@@ -1,7 +1,5 @@
 from .equity_vol_curve import *
 from .equity_vol_surface import *
-from .fx_vol_surface import *
+# from .fx_vol_surface import *
 from .fx_vol_surface_plus import *
 from .ibor_cap_vol_curve import *
-
-
