@@ -166,7 +166,8 @@ def bermudan_swaption_tree_fast(texp, tmat,
     ###########################################################################
 
     fixed_legFlows = np.zeros(num_time_steps)
-    float_leg_values = np.ones(num_time_steps)  # Initialise it with ones CHANGE
+    # Initialise it with ones CHANGE
+    float_leg_values = np.ones(num_time_steps)
     num_coupons = len(coupon_times)
 
     # swap fixed leg flows go all the way out to the swap maturity date
@@ -760,7 +761,7 @@ def callable_puttable_bond_tree_fast(coupon_times, coupon_flows,
 ###############################################################################
 
 
-@njit(fastmath=True)
+@njit(fastmath=True, cache=True)
 def build_tree_fast(a, sigma, tree_times, num_time_steps, discount_factors):
     """ Calibrate the tree to a term structure of interest rates. """
 
