@@ -10,7 +10,6 @@ import numpy as np
 
 from ..utils.error import FinError
 from ..utils.math import norminvcdf
-from ..utils.helpers import label_to_string
 
 ###############################################################################
 
@@ -47,7 +46,8 @@ class FinProcessSimulator():
             return paths
 
         elif process_type == ProcessTypes.HESTON:
-            (stock_price, drift, v0, kappa, theta, sigma, rho, scheme) = model_params
+            (stock_price, drift, v0, kappa, theta,
+             sigma, rho, scheme) = model_params
             paths = get_heston_paths(num_paths,
                                      numAnnSteps,
                                      t,
@@ -222,6 +222,7 @@ class FinGBMNumericalScheme(Enum):
 
 ###############################################################################
 
+
 @njit(float64[:, :](int64, int64, float64, float64, float64,
                     float64, int64, int64), cache=True, fastmath=True)
 def get_gbm_paths(num_paths, numAnnSteps, t, mu, stock_price, sigma, scheme, seed):
@@ -272,6 +273,7 @@ class FinVasicekNumericalScheme(Enum):
 
 ###############################################################################
 
+
 @njit(float64[:, :](int64, int64, float64, float64, float64,
                     float64, float64, int64, int64), cache=True, fastmath=True)
 def get_vasicek_paths(num_paths,
@@ -326,6 +328,7 @@ class CIRNumericalScheme(Enum):
 
 ###############################################################################
 
+
 @njit(float64[:, :](int64, int64, float64, float64, float64,
                     float64, float64, int64, int64), cache=True, fastmath=True)
 def get_cir_paths(num_paths,
