@@ -35,6 +35,7 @@ from ...utils.calendar import CalendarTypes
 from ...utils.calendar import BusDayAdjustTypes
 from ...utils.calendar import DateGenRuleTypes
 from ...utils.helpers import label_to_string, check_argument_types
+from ...utils.math import npv
 from ...market.curves.discount_curve import DiscountCurve
 
 
@@ -49,6 +50,7 @@ from enum import Enum
 
 
 class YTMCalcType(Enum):
+    ZERO = 0,
     UK_DMO = 1,
     US_STREET = 2,
     US_TREASURY = 3
@@ -81,10 +83,8 @@ def _g(oas, *args):
     obj_fn = px - price
     return obj_fn
 
-
 ###############################################################################
 
-
 class Bond:
     """ Class for fixed coupon bonds and performing related analytics. These
     are bullet bonds which means they have regular coupon payments of a known
@@ -96,10 +96,12 @@ class Bond:
                  coupon: float,  # Annualised bond coupon
                  freq_type: FrequencyTypes,
                  accrual_type: DayCountTypes,
-                 face_amount: float = 100.0):
+                 face_amount: float = 100.0,
+                 calendar_type: CalendarTypes = CalendarTypes.WEEKEND):
         """ Create Bond object by providing the issue date, maturity Date,
         coupon frequency, annualised coupon, the accrual convention type, face
-        amount and the number of ex-dividend days. """
+        amount and the number of ex-dividend days. A calendar type is used 
+        to determine holidays from which coupon dates might be shifted."""
 
         check_argument_types(self.__init__, locals())
 
@@ -108,50 +110,90 @@ class Bond:
 
         self._issue_date = issue_date
         self._maturity_date = maturity_date
+
+        if coupon == 0.0 or freq_type == FrequencyTypes.ZERO or accrual_type == accrual_type.ZERO:
+            raise FinError(f"Zero coupon bonds must use BondZero class. coupon:{coupon}. freq:{freq_type}" +
+                           f"accrual_type:{accrual_type}")
+
         self._coupon = coupon
         self._freq_type = freq_type
+
         self._accrual_type = accrual_type
         self._frequency = annual_frequency(freq_type)
         self._face_amount = face_amount  # This is the bond holding size
         self._par = 100.0  # This is how price is quoted and amount at maturity
         self._redemption = 1.0  # This is amount paid at maturity
+        self._calendar_type = calendar_type
 
-        self._flow_dates = []
+        self._coupon_dates = []
+        self._payment_dates = []  # Actual payment dates are adjusted
         self._flow_amounts = []
 
         self._accrued_interest = None
         self._accrued_days = 0.0
         self._alpha = 0.0
 
-        self._calculate_flow_dates()
+        self._calculate_coupon_dates()
         self._calculate_flows()
 
     ###########################################################################
 
-    def _calculate_flow_dates(self):
-        """ Determine the bond cash flow payment dates."""
+    def _calculate_coupon_dates(self):
+        """ Determine the bond coupon dates. Note that for analytical 
+        calculations these are not usually adjusted and so may fall on a 
+        weekend or holiday. 
+        """
 
         # This should only be called once from init
-
-        calendar_type = CalendarTypes.NONE
-        bus_day_rule_type = BusDayAdjustTypes.NONE
+        bus_day_rule_type = BusDayAdjustTypes.FOLLOWING
         date_gen_rule_type = DateGenRuleTypes.BACKWARD
 
-        self._flow_dates = Schedule(self._issue_date,
+        self._coupon_dates = Schedule(self._issue_date,
                                     self._maturity_date,
                                     self._freq_type,
-                                    calendar_type,
+                                    CalendarTypes.NONE,
                                     bus_day_rule_type,
                                     date_gen_rule_type)._generate()
 
     ###########################################################################
 
+    def _calculate_payment_dates(self):
+        """ For the actual payment dates, they are adjusted 
+        and so we then use the calendar payment dates. Although payments are 
+        calculated as though coupon periods are the same length, payments that 
+        fall on a Saturday or Sunday can only be made on the next business day
+        """
+
+        # dates are adjusted forward to the next business day            
+        bus_day_adj_type = BusDayAdjustTypes.FOLLOWING
+        calendar = Calendar(self._calendar_type)
+
+        self._calculate_coupon_dates()
+
+        self._payment_dates = []
+
+        # Expect at least an issue date and a maturity date - if not - problem
+        if len(self._coupon_dates) < 2:
+            raise FinError("Unable to calculate payment dates with only one payment")
+
+        # I do not adjust the first date as it is the issue date
+        self._payment_dates.append(self._coupon_dates[0])
+
+        for cpn_date in self._coupon_dates[1:]:
+            pmt_date = calendar.adjust(cpn_date,
+                                       bus_day_adj_type)
+
+            self._payment_dates.append(pmt_date)
+
+    ###########################################################################
+
     def _calculate_flows(self):
-        """ Determine the bond cash flow payment amounts without principal """
+        """ Determine the bond cash flow payment amounts without principal. 
+        There is no adjustment based on the adjusted payment dates. """
 
         self._flow_amounts = [0.0]
 
-        for _ in self._flow_dates[1:]:
+        for _ in self._coupon_dates[1:]:
             cpn = self._coupon / self._frequency
             self._flow_amounts.append(cpn)
 
@@ -175,11 +217,15 @@ class Bond:
 
         f = annual_frequency(self._freq_type)
         c = self._coupon
+
+        if convention == YTMCalcType.ZERO:
+            raise FinError("Zero coupon bonds must use BondZero class.")
+
         v = 1.0 / (1.0 + ytm / f)
 
         # n is the number of flows after the next coupon
         n = 0
-        for dt in self._flow_dates:
+        for dt in self._coupon_dates:
             if dt > settlement_date:
                 n += 1
         n = n - 1
@@ -207,7 +253,6 @@ class Bond:
                 vw = 1.0 / (1.0 + self._alpha * ytm / f)
                 fp = (vw) * (term1 + term2 + term3 + term4)
         elif convention == YTMCalcType.US_STREET:
-            vw = 1.0 / (1.0 + self._alpha * ytm / f)
             if n == 0:
                 vw = 1.0 / (1.0 + self._alpha * ytm / f)
                 fp = vw * (self._redemption + c / f)
@@ -348,7 +393,7 @@ class Bond:
         df = 1.0
         dfSettle = discount_curve.df(settlement_date)
 
-        for dt in self._flow_dates[1:]:
+        for dt in self._coupon_dates[1:]:
 
             # coupons paid on the settlement date are included
             if dt >= settlement_date:
@@ -397,7 +442,7 @@ class Bond:
             argtuple = (self, settlement_date, full_price, convention)
 
             ytm = optimize.newton(_f,
-                                  x0=0.05,  # guess initial value of 10%
+                                  x0=0.05,  # guess initial value of 5%
                                   fprime=None,
                                   args=argtuple,
                                   tol=1e-8,
@@ -416,7 +461,7 @@ class Bond:
     def calc_accrued_interest(self,
                               settlement_date: Date,
                               num_ex_dividend_days: int = 0,
-                              calendar_type: CalendarTypes=CalendarTypes.WEEKEND):
+                              calendar_type: CalendarTypes = CalendarTypes.WEEKEND):
         """ Calculate the amount of coupon that has accrued between the
         previous coupon date and the settlement date. Note that for some day
         count schemes (such as 30E/360) this is not actually the number of days
@@ -426,21 +471,22 @@ class Bond:
         calendar to be used - NONE means only calendar days, WEEKEND is only
         weekends or you can specify a country calendar for business days."""
 
-        num_flows = len(self._flow_dates)
+        num_flows = len(self._coupon_dates)
 
         if num_flows == 0:
             raise FinError("Accrued interest - not enough flow dates.")
 
         for iFlow in range(1, num_flows):
             # coupons paid on a settlement date are paid
-            if self._flow_dates[iFlow] >= settlement_date:
-                self._pcd = self._flow_dates[iFlow - 1]
-                self._ncd = self._flow_dates[iFlow]
+            if self._coupon_dates[iFlow] >= settlement_date:
+                self._pcd = self._coupon_dates[iFlow - 1]
+                self._ncd = self._coupon_dates[iFlow]
                 break
 
         dc = DayCount(self._accrual_type)
         cal = Calendar(calendar_type)
-        exDividend_date = cal.add_business_days(self._ncd, -num_ex_dividend_days)
+        exDividend_date = cal.add_business_days(
+            self._ncd, -num_ex_dividend_days)
 
         (acc_factor, num, _) = dc.year_frac(self._pcd,
                                             settlement_date,
@@ -453,7 +499,6 @@ class Bond:
         self._alpha = 1.0 - acc_factor * self._frequency
         self._accrued_interest = acc_factor * self._face_amount * self._coupon
         self._accrued_days = num
-
         return self._accrued_interest
 
     ###########################################################################
@@ -480,7 +525,7 @@ class Bond:
         pvIbor = 0.0
         prev_date = self._pcd
 
-        for dt in self._flow_dates[1:]:
+        for dt in self._coupon_dates[1:]:
 
             # coupons paid on a settlement date are included
             if dt >= settlement_date:
@@ -526,7 +571,7 @@ class Bond:
         c = self._coupon
 
         pv = 0.0
-        for dt in self._flow_dates[1:]:
+        for dt in self._coupon_dates[1:]:
 
             # coupons paid on a settlement date are included
             if dt >= settlement_date:
@@ -589,20 +634,34 @@ class Bond:
 
     ###########################################################################
 
-    def print_flows(self,
-                    settlement_date: Date):
+    def coupon_dates(self,
+        settlement_date: Date):
         """ Print a list of the unadjusted coupon payment dates used in
         analytic calculations for the bond. """
 
         flow = self._face_amount * self._coupon / self._frequency
 
-        for dt in self._flow_dates[1:-1]:
+        flow_str = ""
+
+        for dt in self._coupon_dates[1:-1]:
             # coupons paid on a settlement date are included
             if dt >= settlement_date:
-                print("%12s" % dt, " %12.2f " % flow)
+                flow_str += ("%12s %12.2f \n" % (dt, flow))
 
         redemption_amount = self._face_amount + flow
-        print("%12s" % self._flow_dates[-1], " %12.2f " % redemption_amount)
+        flow_str += ("%12s %12.2f \n"
+                     % (self._coupon_dates[-1], redemption_amount))
+
+        return flow_str
+
+    ###########################################################################
+
+    def print_coupon_dates(self,
+                    settlement_date: Date):
+        """ Print a list of the unadjusted coupon payment dates used in
+        analytic calculations for the bond. """
+
+        print(self.coupon_dates(settlement_date))
 
     ###########################################################################
 
@@ -629,7 +688,7 @@ class Bond:
         defaultingPrincipalPVPayStart = 0.0
         defaultingPrincipalPVPayEnd = 0.0
 
-        for dt in self._flow_dates[1:]:
+        for dt in self._coupon_dates[1:]:
 
             # coupons paid on a settlement date are included
             if dt >= settlement_date:
@@ -679,12 +738,51 @@ class Bond:
 
     ###########################################################################
 
+    def calc_ror(self,
+                 begin_date: Date,
+                 end_date: Date,
+                 begin_ytm: float,
+                 end_ytm: float,
+                 convention: YTMCalcType = YTMCalcType.US_STREET):
+        """
+        Calculate the rate of total return(capital return and interest) given a BUY YTM and a SELL YTM of this bond.
+        This function computes the full prices at buying and selling, plus the coupon payments during the period.
+        It returns a tuple which includes a simple rate of return, a compounded IRR and the PnL.
+        """
+        buy_price = self.full_price_from_ytm(begin_date, begin_ytm, convention)
+        sell_price = self.full_price_from_ytm(end_date, end_ytm, convention)
+        dates_cfs = zip(self._coupon_dates, self._flow_amounts)
+        # The coupon or par payments on buying date belong to the buyer.
+        # The coupon or par payments on selling date are given to the new buyer.
+        dates_cfs = [(d, c * self._par) for (d, c) in dates_cfs if (d >= begin_date) and (d < end_date)]
+        dates_cfs.append((begin_date, -buy_price))
+        dates_cfs.append((end_date, sell_price))
+        times_cfs = [((d - begin_date)/365, c) for (d, c) in dates_cfs]
+        pnl = sum(c for (t, c) in times_cfs)
+        simple_return = (pnl / buy_price) * 365 / (end_date - begin_date)
+        brentq_up_bound = 5
+        brentq_down_bound = -0.9999
+        # in case brentq cannot find the irr root
+        if simple_return > brentq_up_bound or simple_return < brentq_down_bound:
+            irr = simple_return
+        else:
+            irr = optimize.brentq(npv,
+                                  a=brentq_down_bound,  # f(a) and f(b) must have opposite signs
+                                  b=brentq_up_bound,
+                                  xtol=1e-8,
+                                  args=(np.array(times_cfs),)
+                                  )
+
+        return simple_return, irr, pnl
+
+    ###########################################################################
+
     def __repr__(self):
 
         s = label_to_string("OBJECT TYPE", type(self).__name__)
         s += label_to_string("ISSUE DATE", self._issue_date)
         s += label_to_string("MATURITY DATE", self._maturity_date)
-        s += label_to_string("COUPON", self._coupon)
+        s += label_to_string("COUPON (%)", self._coupon*100.0)
         s += label_to_string("FREQUENCY", self._freq_type)
         s += label_to_string("ACCRUAL TYPE", self._accrual_type)
         s += label_to_string("FACE AMOUNT", self._face_amount, "")
