@@ -53,7 +53,8 @@ class BondFRN:
                  quoted_margin: float,  # Fixed spread paid on top of index
                  freq_type: FrequencyTypes,
                  accrual_type: DayCountTypes,
-                 face_amount: float = 100.0):
+                 face_amount: float = 100.0, 
+                 calendar_type:CalendarTypes = CalendarTypes.WEEKEND):
         """ Create FinFloatingRateNote object given its maturity date, its
         quoted margin, coupon frequency, accrual type. Face is the size of
         the position and par is the notional on which price is quoted. """
@@ -65,36 +66,35 @@ class BondFRN:
         self._quoted_margin = quoted_margin
         self._freq_type = freq_type
         self._accrual_type = accrual_type
-        self._flow_dates = []
+        self._coupon_dates = []
         self._frequency = annual_frequency(freq_type)
         self._face_amount = face_amount  # This is the position size
         self._par = 100.0  # This is how price is quoted
         self._redemption = 1.0  # This is amount paid at maturity TODO NOT USED
-
-        self._flow_dates = []
+        self._calendar_type = calendar_type
+        self._coupon_dates = []
         self._flow_amounts = []
 
         self._settlement_date = Date(1, 1, 1900)
         self._accrued_interest = None
         self._accrued_days = 0.0
 
-        self._calculate_flow_dates()
+        self._calculate_coupon_dates()
 
     ###############################################################################
 
-    def _calculate_flow_dates(self):
+    def _calculate_coupon_dates(self):
         """ Determine the bond cashflow payment dates. """
 
-        # This should only be called once from init 
+        # This should only be called once from init
 
-        calendar_type = CalendarTypes.NONE
         bus_day_rule_type = BusDayAdjustTypes.NONE
         date_gen_rule_type = DateGenRuleTypes.BACKWARD
 
-        self._flow_dates = Schedule(self._issue_date,
+        self._coupon_dates = Schedule(self._issue_date,
                                     self._maturity_date,
                                     self._freq_type,
-                                    calendar_type,
+                                    self._calendar_type,
                                     bus_day_rule_type,
                                     date_gen_rule_type)._generate()
 
@@ -118,7 +118,7 @@ class BondFRN:
         day_counter = DayCount(self._accrual_type)
 
         q = self._quoted_margin
-        num_flows = len(self._flow_dates)
+        num_flows = len(self._coupon_dates)
 
         # We discount using Libor over the period from settlement to the ncd
         (alpha, _, _) = day_counter.year_frac(settlement_date, self._ncd)
@@ -131,9 +131,9 @@ class BondFRN:
         # Now do all subsequent coupons that fall after the ncd
         for iFlow in range(1, num_flows):
 
-            if self._flow_dates[iFlow] > self._ncd:
-                pcd = self._flow_dates[iFlow - 1]
-                ncd = self._flow_dates[iFlow]
+            if self._coupon_dates[iFlow] > self._ncd:
+                pcd = self._coupon_dates[iFlow - 1]
+                ncd = self._coupon_dates[iFlow]
                 (alpha, _, _) = day_counter.year_frac(pcd, ncd)
 
                 df = df / (1.0 + alpha * (future_ibor + dm))
@@ -169,11 +169,11 @@ class BondFRN:
     ###############################################################################
 
     def dollar_duration(self,
-                       settlement_date: Date,
-                       next_coupon: float,
-                       current_ibor: float,
-                       future_ibor: float,
-                       dm: float):
+                        settlement_date: Date,
+                        next_coupon: float,
+                        current_ibor: float,
+                        future_ibor: float,
+                        dm: float):
         """ Calculate the risk or dP/dy of the bond by bumping. This is also
         known as the DV01 in Bloomberg. """
 
@@ -197,11 +197,11 @@ class BondFRN:
     ###############################################################################
 
     def dollar_credit_duration(self,
-                             settlement_date: Date,
-                             next_coupon: float,
-                             current_ibor: float,
-                             future_ibor: float,
-                             dm: float):
+                               settlement_date: Date,
+                               next_coupon: float,
+                               current_ibor: float,
+                               future_ibor: float,
+                               dm: float):
         """ Calculate the risk or dP/dy of the bond by bumping. """
 
         if dm > 10.0:
@@ -228,19 +228,19 @@ class BondFRN:
     ###############################################################################
 
     def macauley_duration(self,
-                             settlement_date: Date,
-                             next_coupon: float,
-                             current_ibor: float,
-                             future_ibor: float,
-                             dm: float):
+                          settlement_date: Date,
+                          next_coupon: float,
+                          current_ibor: float,
+                          future_ibor: float,
+                          dm: float):
         """ Calculate the Macauley duration of the FRN on a settlement date
         given its yield to maturity. """
 
         dd = self.dollar_duration(settlement_date,
-                                 next_coupon,
-                                 current_ibor,
-                                 future_ibor,
-                                 dm)
+                                  next_coupon,
+                                  current_ibor,
+                                  future_ibor,
+                                  dm)
 
         fp = self.full_price_from_dm(settlement_date,
                                      next_coupon,
@@ -254,11 +254,11 @@ class BondFRN:
     ###############################################################################
 
     def modified_duration(self,
-                             settlement_date: Date,
-                             next_coupon: float,
-                             current_ibor: float,
-                             future_ibor: float,
-                             dm: float):
+                          settlement_date: Date,
+                          next_coupon: float,
+                          current_ibor: float,
+                          future_ibor: float,
+                          dm: float):
         """ Calculate the modified duration of the bond on a settlement date
         using standard model based on assumptions about future Ibor rates. The
         next Ibor payment which has reset is entered, so to is the current
@@ -267,10 +267,10 @@ class BondFRN:
         margin. """
 
         dd = self.dollar_duration(settlement_date,
-                                 next_coupon,
-                                 current_ibor,
-                                 future_ibor,
-                                 dm)
+                                  next_coupon,
+                                  current_ibor,
+                                  future_ibor,
+                                  dm)
 
         fp = self.full_price_from_dm(settlement_date,
                                      next_coupon,
@@ -283,11 +283,11 @@ class BondFRN:
     ###############################################################################
 
     def modified_credit_duration(self,
-                               settlement_date: Date,
-                               next_coupon: float,
-                               current_ibor: float,
-                               future_ibor: float,
-                               dm: float):
+                                 settlement_date: Date,
+                                 next_coupon: float,
+                                 current_ibor: float,
+                                 future_ibor: float,
+                                 dm: float):
         """ Calculate the modified duration of the bond on a settlement date
         using standard model based on assumptions about future Ibor rates. The
         next Ibor payment which has reset is entered, so to is the current
@@ -296,10 +296,10 @@ class BondFRN:
         margin. """
 
         dd = self.dollar_credit_duration(settlement_date,
-                                       next_coupon,
-                                       current_ibor,
-                                       future_ibor,
-                                       dm)
+                                         next_coupon,
+                                         current_ibor,
+                                         future_ibor,
+                                         dm)
 
         fp = self.full_price_from_dm(settlement_date,
                                      next_coupon,
@@ -312,11 +312,11 @@ class BondFRN:
     ###############################################################################
 
     def convexity_from_dm(self,
-                        settlement_date: Date,
-                        next_coupon: float,
-                        current_ibor: float,
-                        future_ibor: float,
-                        dm: float):
+                          settlement_date: Date,
+                          next_coupon: float,
+                          current_ibor: float,
+                          future_ibor: float,
+                          dm: float):
         """ Calculate the bond convexity from the discount margin (DM) using a
         standard model based on assumptions about future Ibor rates. The
         next Ibor payment which has reset is entered, so to is the current
@@ -350,11 +350,11 @@ class BondFRN:
     ###############################################################################
 
     def clean_price_from_dm(self,
-                          settlement_date: Date,
-                          next_coupon: float,
-                          current_ibor: float,
-                          future_ibor: float,
-                          dm: float):
+                            settlement_date: Date,
+                            next_coupon: float,
+                            current_ibor: float,
+                            future_ibor: float,
+                            dm: float):
         """ Calculate the bond clean price from the discount margin
         using standard model based on assumptions about future Ibor rates. The
         next Ibor payment which has reset is entered, so to is the current
@@ -380,11 +380,11 @@ class BondFRN:
     ###############################################################################
 
     def discount_margin(self,
-                       settlement_date: Date,
-                       next_coupon: float,
-                       current_ibor: float,
-                       future_ibor: float,
-                       clean_price: float):
+                        settlement_date: Date,
+                        next_coupon: float,
+                        current_ibor: float,
+                        future_ibor: float,
+                        clean_price: float):
         """ Calculate the bond's yield to maturity by solving the price
         yield relationship using a one-dimensional root solver. """
 
@@ -417,7 +417,7 @@ class BondFRN:
         previous coupon date and the settlement date. Ex-dividend dates are 
         not handled. Contact me if you need this functionality. """
 
-        num_flows = len(self._flow_dates)
+        num_flows = len(self._coupon_dates)
 
         if num_flows == 0:
             raise FinError("Accrued interest - not enough flow dates.")
@@ -425,9 +425,9 @@ class BondFRN:
         dc = DayCount(self._accrual_type)
 
         for i in range(1, num_flows):
-            if self._flow_dates[i] > settlement_date:
-                self._pcd = self._flow_dates[i - 1]
-                self._ncd = self._flow_dates[i]
+            if self._coupon_dates[i] > settlement_date:
+                self._pcd = self._coupon_dates[i - 1]
+                self._ncd = self._coupon_dates[i]
                 break
 
         (acc_factor, num, _) = dc.year_frac(self._pcd,
@@ -444,14 +444,14 @@ class BondFRN:
     ###############################################################################
 
     def print_flows(self,
-                   settlement_date: Date):
+                    settlement_date: Date):
         """ Print a list of the unadjusted coupon payment dates used in
         analytic calculations for the bond. """
-        self._calculate_flow_dates()
-        for dt in self._flow_dates[1:-1]:
+        self._calculate_coupon_dates()
+        for dt in self._coupon_dates[1:-1]:
             print(dt)
 
-        print(self._flow_dates[-1])
+        print(self._coupon_dates[-1])
 
     ###############################################################################
 
@@ -459,7 +459,8 @@ class BondFRN:
         s = label_to_string("OBJECT TYPE", type(self).__name__)
         s += label_to_string("ISSUE DATE", self._issue_date)
         s += label_to_string("MATURITY DATE", self._maturity_date)
-        s += label_to_string("QUOTED MARGIN (bp)", self._quoted_margin * 10000.0)
+        s += label_to_string("QUOTED MARGIN (bp)",
+                             self._quoted_margin * 10000.0)
         s += label_to_string("FREQUENCY", self._freq_type)
         s += label_to_string("ACCRUAL TYPE", self._accrual_type)
         s += label_to_string("FACE AMOUNT", self._face_amount)
