@@ -399,6 +399,14 @@ class EquityAsianOption:
         if valuation_date > self._expiry_date:
             raise FinError("Value date after expiry date.")
 
+        if discount_curve._valuation_date != valuation_date:
+            raise FinError(
+                "Discount Curve valuation date not same as option valuation date")
+
+        if dividend_curve._valuation_date != valuation_date:
+            raise FinError(
+                "Dividend Curve valuation date not same as option valuation date")
+
         if method == AsianOptionValuationMethods.GEOMETRIC:
             v = self._value_geometric(valuation_date,
                                       stock_price,
