@@ -66,6 +66,20 @@ class EquityFloatLookbackOption(EquityOption):
         """ Valuation of the Floating Lookback option using Black-Scholes using
         the formulae derived by Goldman, Sosin and Gatto (1979). """
 
+        if isinstance(valuation_date, Date) == False:
+            raise FinError("Valuation date is not a Date")
+
+        if valuation_date > self._expiry_date:
+            raise FinError("Valuation date after expiry date.")
+
+        if discount_curve._valuation_date != valuation_date:
+            raise FinError(
+                "Discount Curve valuation date not same as option valuation date")
+
+        if dividend_curve._valuation_date != valuation_date:
+            raise FinError(
+                "Dividend Curve valuation date not same as option valuation date")
+
         t = (self._expiry_date - valuation_date) / gDaysInYear
         df = discount_curve.df(self._expiry_date)
 
@@ -110,7 +124,7 @@ class EquityFloatLookbackOption(EquityOption):
                 term = - expbt * N(-a1)
             else:
                 term = ((s0 / smin)**(-w)) \
-                       * N(-a1 + 2.0 * b * np.sqrt(t) / v) - expbt * N(-a1)
+                    * N(-a1 + 2.0 * b * np.sqrt(t) / v) - expbt * N(-a1)
 
             v = s0 * dq * N(a1) - smin * df * N(a2) + s0 * df * u * term
 
@@ -125,7 +139,7 @@ class EquityFloatLookbackOption(EquityOption):
                 term = expbt * N(b1)
             else:
                 term = (-(s0 / smax)**(-w)) * \
-                       N(b1 - 2.0 * b * np.sqrt(t) / v) + expbt * N(b1)
+                    N(b1 - 2.0 * b * np.sqrt(t) / v) + expbt * N(b1)
 
             v = smax * df * N(-b2) - s0 * dq * N(-b1) + s0 * df * u * term
 
