@@ -8,6 +8,7 @@ from enum import Enum
 
 
 from ...utils.global_vars import gDaysInYear
+from ...utils.global_types import TouchOptionTypes
 from ...utils.error import FinError
 from ...products.equity.equity_option import EquityOption
 from ...utils.helpers import label_to_string, check_argument_types
@@ -25,23 +26,6 @@ from ...utils.math import n_vect
 ###############################################################################
 
 
-class FinTouchOptionPayoffTypes(Enum):
-    DOWN_AND_IN_CASH_AT_HIT = 1,         # S0>H pays $1 at hit time from above
-    UP_AND_IN_CASH_AT_HIT = 2,           # S0<H pays $1 at hit time from below
-    DOWN_AND_IN_CASH_AT_EXPIRY = 3,      # S0>H pays $1 at T if hit from above
-    UP_AND_IN_CASH_AT_EXPIRY = 4,        # S0<H pays $1 at T if hit from below
-    DOWN_AND_OUT_CASH_OR_NOTHING = 5,    # S0>H pays $1 at T if S>H for all t<T
-    UP_AND_OUT_CASH_OR_NOTHING = 6,      # S0<H pays $1 at T if S<H for all t<T
-    DOWN_AND_IN_ASSET_AT_HIT = 7,        # S0>H pays H at hit time from above
-    UP_AND_IN_ASSET_AT_HIT = 8,          # S0>H pays H at hit time from below
-    DOWN_AND_IN_ASSET_AT_EXPIRY = 9,     # S0>H pays S(T) at T if S<H for t < T
-    UP_AND_IN_ASSET_AT_EXPIRY = 10,      # S0<H pays S(T) at T if S>H for t < T
-    DOWN_AND_OUT_ASSET_OR_NOTHING = 11,  # S0>H pays S(T) at T if S>H for t < T
-    UP_AND_OUT_ASSET_OR_NOTHING = 12     # S0<H pays S(T) at T if S<H for t < T
-
-###############################################################################
-
-
 @njit(fastmath=True, cache=True)
 def _barrier_pay_one_at_hit_pv_down(s, H, r, dt):
     """ Pay $1 if the stock crosses the barrier H from above. PV payment. """
@@ -147,7 +131,7 @@ class EquityOneTouchOption(EquityOption):
 
     def __init__(self,
                  expiry_date: Date,
-                 option_type: FinTouchOptionPayoffTypes,
+                 option_type: TouchOptionTypes,
                  barrier_price: float,
                  payment_size: float = 1.0):
         """ Create the one touch option by defining its expiry date and the
@@ -174,8 +158,19 @@ class EquityOneTouchOption(EquityOption):
 
         DEBUG_MODE = False
 
+        if isinstance(valuation_date, Date) is False:
+            raise FinError("Valuation date is not a Date")
+
         if valuation_date > self._expiry_date:
-            raise FinError("Value date after expiry date.")
+            raise FinError("Valuation date after expiry date.")
+
+        if discount_curve._valuation_date != valuation_date:
+            raise FinError(
+                "Discount Curve date not same as option valuation date")
+
+        if dividend_curve._valuation_date != valuation_date:
+            raise FinError(
+                "Dividend Curve date not same as option valuation date")
 
         t = (self._expiry_date - valuation_date) / gDaysInYear
         t = max(t, 1e-6)
@@ -207,7 +202,7 @@ class EquityOneTouchOption(EquityOption):
 
         # Reference Option Pricing Formulas by Espen Gaarder Haug. Page 176.
 
-        if self._option_type == FinTouchOptionPayoffTypes.DOWN_AND_IN_CASH_AT_HIT:
+        if self._option_type == TouchOptionTypes.DOWN_AND_IN_CASH_AT_HIT:
             # HAUG 1
 
             if np.any(s0 <= H):
@@ -216,11 +211,12 @@ class EquityOneTouchOption(EquityOption):
             eta = 1.0
             z = np.log(H/s0) / v / sqrtT + lam * v * sqrtT
             A5_1 = np.power(H/s0, mu + lam) * n_vect(eta * z)
-            A5_2 = np.power(H/s0, mu - lam) * n_vect(eta * z - 2.0 * eta * lam * v * sqrtT)
+            A5_2 = np.power(H/s0, mu - lam) * n_vect(eta *
+                                                     z - 2.0 * eta * lam * v * sqrtT)
             v = (A5_1 + A5_2) * K
             return v
 
-        elif self._option_type == FinTouchOptionPayoffTypes.UP_AND_IN_CASH_AT_HIT:
+        elif self._option_type == TouchOptionTypes.UP_AND_IN_CASH_AT_HIT:
             # HAUG 2
 
             if np.any(s0 >= H):
@@ -234,7 +230,7 @@ class EquityOneTouchOption(EquityOption):
             v = (A5_1 + A5_2) * K
             return v
 
-        elif self._option_type == FinTouchOptionPayoffTypes.DOWN_AND_IN_ASSET_AT_HIT:
+        elif self._option_type == TouchOptionTypes.DOWN_AND_IN_ASSET_AT_HIT:
             # HAUG 3
 
             if np.any(s0 <= H):
@@ -249,7 +245,7 @@ class EquityOneTouchOption(EquityOption):
             v = (A5_1 + A5_2) * K
             return v
 
-        elif self._option_type == FinTouchOptionPayoffTypes.UP_AND_IN_ASSET_AT_HIT:
+        elif self._option_type == TouchOptionTypes.UP_AND_IN_ASSET_AT_HIT:
             # HAUG 4
 
             if np.any(s0 >= H):
@@ -264,7 +260,7 @@ class EquityOneTouchOption(EquityOption):
             v = (A5_1 + A5_2) * K
             return v
 
-        elif self._option_type == FinTouchOptionPayoffTypes.DOWN_AND_IN_CASH_AT_EXPIRY:
+        elif self._option_type == TouchOptionTypes.DOWN_AND_IN_CASH_AT_EXPIRY:
             # HAUG 5
 
             if np.any(s0 <= H):
@@ -275,11 +271,12 @@ class EquityOneTouchOption(EquityOption):
             x2 = np.log(s0/H) / v / sqrtT + (mu + 1.0) * v * sqrtT
             y2 = np.log(H/s0) / v / sqrtT + (mu + 1.0) * v * sqrtT
             B2 = K * df * n_vect(phi * x2 - phi * v * sqrtT)
-            B4 = K * df * np.power(H/s0, 2.0 * mu) * n_vect(eta * y2 - eta * v * sqrtT)
+            B4 = K * df * np.power(H/s0, 2.0 * mu) * \
+                n_vect(eta * y2 - eta * v * sqrtT)
             v = (B2 + B4)
             return v
 
-        elif self._option_type == FinTouchOptionPayoffTypes.UP_AND_IN_CASH_AT_EXPIRY:
+        elif self._option_type == TouchOptionTypes.UP_AND_IN_CASH_AT_EXPIRY:
             # HAUG 6
 
             if np.any(s0 >= H):
@@ -291,11 +288,12 @@ class EquityOneTouchOption(EquityOption):
             x2 = np.log(s0/H) / v / sqrtT + (mu + 1.0) * v * sqrtT
             y2 = np.log(H/s0) / v / sqrtT + (mu + 1.0) * v * sqrtT
             B2 = K * df * n_vect(phi * x2 - phi * v * sqrtT)
-            B4 = K * df * np.power(H/s0, 2.0 * mu) * n_vect(eta * y2 - eta * v * sqrtT)
+            B4 = K * df * np.power(H/s0, 2.0 * mu) * \
+                n_vect(eta * y2 - eta * v * sqrtT)
             v = (B2 + B4)
             return v
 
-        elif self._option_type == FinTouchOptionPayoffTypes.DOWN_AND_IN_ASSET_AT_EXPIRY:
+        elif self._option_type == TouchOptionTypes.DOWN_AND_IN_ASSET_AT_EXPIRY:
             # HAUG 7
 
             if np.any(s0 <= H):
@@ -311,7 +309,7 @@ class EquityOneTouchOption(EquityOption):
             v = (A2 + A4)
             return v
 
-        elif self._option_type == FinTouchOptionPayoffTypes.UP_AND_IN_ASSET_AT_EXPIRY:
+        elif self._option_type == TouchOptionTypes.UP_AND_IN_ASSET_AT_EXPIRY:
             # HAUG 8
 
             if np.any(s0 >= H):
@@ -327,7 +325,7 @@ class EquityOneTouchOption(EquityOption):
             v = (A2 + A4)
             return v
 
-        elif self._option_type == FinTouchOptionPayoffTypes.DOWN_AND_OUT_CASH_OR_NOTHING:
+        elif self._option_type == TouchOptionTypes.DOWN_AND_OUT_CASH_OR_NOTHING:
             # HAUG 9
 
             if np.any(s0 <= H):
@@ -339,11 +337,12 @@ class EquityOneTouchOption(EquityOption):
             x2 = np.log(s0/H) / v / sqrtT + (mu + 1.0) * v * sqrtT
             y2 = np.log(H/s0) / v / sqrtT + (mu + 1.0) * v * sqrtT
             B2 = K * df * n_vect(phi * x2 - phi * v * sqrtT)
-            B4 = K * df * np.power(H/s0, 2.0 * mu) * n_vect(eta * y2 - eta * v * sqrtT)
+            B4 = K * df * np.power(H/s0, 2.0 * mu) * \
+                n_vect(eta * y2 - eta * v * sqrtT)
             v = (B2 - B4)
             return v
 
-        elif self._option_type == FinTouchOptionPayoffTypes.UP_AND_OUT_CASH_OR_NOTHING:
+        elif self._option_type == TouchOptionTypes.UP_AND_OUT_CASH_OR_NOTHING:
             # HAUG 10
 
             if np.any(s0 >= H):
@@ -355,11 +354,12 @@ class EquityOneTouchOption(EquityOption):
             x2 = np.log(s0/H) / v / sqrtT + (mu + 1.0) * v * sqrtT
             y2 = np.log(H/s0) / v / sqrtT + (mu + 1.0) * v * sqrtT
             B2 = K * df * n_vect(phi * x2 - phi * v * sqrtT)
-            B4 = K * df * np.power(H/s0, 2.0 * mu) * n_vect(eta * y2 - eta * v * sqrtT)
+            B4 = K * df * np.power(H/s0, 2.0 * mu) * \
+                n_vect(eta * y2 - eta * v * sqrtT)
             v = (B2 - B4)
             return v
 
-        elif self._option_type == FinTouchOptionPayoffTypes.DOWN_AND_OUT_ASSET_OR_NOTHING:
+        elif self._option_type == TouchOptionTypes.DOWN_AND_OUT_ASSET_OR_NOTHING:
             # HAUG 11
 
             if np.any(s0 <= H):
@@ -376,7 +376,7 @@ class EquityOneTouchOption(EquityOption):
             v = (A2 - A4)
             return v
 
-        elif self._option_type == FinTouchOptionPayoffTypes.UP_AND_OUT_ASSET_OR_NOTHING:
+        elif self._option_type == TouchOptionTypes.UP_AND_OUT_ASSET_OR_NOTHING:
             # HAUG 12
 
             if np.any(s0 >= H):
@@ -436,7 +436,7 @@ class EquityOneTouchOption(EquityOption):
 
         v = 0.0
 
-        if self._option_type == FinTouchOptionPayoffTypes.DOWN_AND_IN_CASH_AT_HIT:
+        if self._option_type == TouchOptionTypes.DOWN_AND_IN_CASH_AT_HIT:
             # HAUG 1
 
             if s0 <= H:
@@ -446,7 +446,7 @@ class EquityOneTouchOption(EquityOption):
             v = v * X
             return v
 
-        elif self._option_type == FinTouchOptionPayoffTypes.UP_AND_IN_CASH_AT_HIT:
+        elif self._option_type == TouchOptionTypes.UP_AND_IN_CASH_AT_HIT:
             # HAUG 2
 
             if s0 >= H:
@@ -456,7 +456,7 @@ class EquityOneTouchOption(EquityOption):
             v = v * X
             return v
 
-        elif self._option_type == FinTouchOptionPayoffTypes.DOWN_AND_IN_ASSET_AT_HIT:
+        elif self._option_type == TouchOptionTypes.DOWN_AND_IN_ASSET_AT_HIT:
             # HAUG 3
 
             if s0 <= H:
@@ -465,7 +465,7 @@ class EquityOneTouchOption(EquityOption):
             v = _barrier_pay_one_at_hit_pv_down(s, H, r, dt) * H
             return v
 
-        elif self._option_type == FinTouchOptionPayoffTypes.UP_AND_IN_ASSET_AT_HIT:
+        elif self._option_type == TouchOptionTypes.UP_AND_IN_ASSET_AT_HIT:
             # HAUG 4
 
             if s0 >= H:
@@ -474,7 +474,7 @@ class EquityOneTouchOption(EquityOption):
             v = _barrier_pay_one_at_hit_pv_up(s, H, r, dt) * H
             return v
 
-        elif self._option_type == FinTouchOptionPayoffTypes.DOWN_AND_IN_CASH_AT_EXPIRY:
+        elif self._option_type == TouchOptionTypes.DOWN_AND_IN_CASH_AT_EXPIRY:
             # HAUG 5
 
             if s0 <= H:
@@ -484,7 +484,7 @@ class EquityOneTouchOption(EquityOption):
             v = v * X * np.exp(-r*t)
             return v
 
-        elif self._option_type == FinTouchOptionPayoffTypes.UP_AND_IN_CASH_AT_EXPIRY:
+        elif self._option_type == TouchOptionTypes.UP_AND_IN_CASH_AT_EXPIRY:
             # HAUG 6
 
             if s0 >= H:
@@ -494,7 +494,7 @@ class EquityOneTouchOption(EquityOption):
             v = v * X * np.exp(-r*t)
             return v
 
-        elif self._option_type == FinTouchOptionPayoffTypes.DOWN_AND_IN_ASSET_AT_EXPIRY:
+        elif self._option_type == TouchOptionTypes.DOWN_AND_IN_ASSET_AT_EXPIRY:
             # HAUG 7
 
             if s0 <= H:
@@ -503,7 +503,7 @@ class EquityOneTouchOption(EquityOption):
             v = _barrier_pay_one_at_hit_pv_down(s, H, 0.0, dt) * H
             return v
 
-        elif self._option_type == FinTouchOptionPayoffTypes.UP_AND_IN_ASSET_AT_EXPIRY:
+        elif self._option_type == TouchOptionTypes.UP_AND_IN_ASSET_AT_EXPIRY:
             # HAUG 8
 
             if s0 >= H:
@@ -512,7 +512,7 @@ class EquityOneTouchOption(EquityOption):
             v = _barrier_pay_one_at_hit_pv_up(s, H, 0.0, dt) * H
             return v
 
-        elif self._option_type == FinTouchOptionPayoffTypes.DOWN_AND_OUT_CASH_OR_NOTHING:
+        elif self._option_type == TouchOptionTypes.DOWN_AND_OUT_CASH_OR_NOTHING:
             # HAUG 9
 
             if s0 <= H:
@@ -522,7 +522,7 @@ class EquityOneTouchOption(EquityOption):
             v = v * X * np.exp(-r*t)
             return v
 
-        elif self._option_type == FinTouchOptionPayoffTypes.UP_AND_OUT_CASH_OR_NOTHING:
+        elif self._option_type == TouchOptionTypes.UP_AND_OUT_CASH_OR_NOTHING:
             # HAUG 10
 
             if s0 >= H:
@@ -532,7 +532,7 @@ class EquityOneTouchOption(EquityOption):
             v = v * X * np.exp(-r*t)
             return v
 
-        elif self._option_type == FinTouchOptionPayoffTypes.DOWN_AND_OUT_ASSET_OR_NOTHING:
+        elif self._option_type == TouchOptionTypes.DOWN_AND_OUT_ASSET_OR_NOTHING:
             # HAUG 11
 
             if s0 <= H:
@@ -542,7 +542,7 @@ class EquityOneTouchOption(EquityOption):
             v = v * np.exp(-r*t)
             return v
 
-        elif self._option_type == FinTouchOptionPayoffTypes.UP_AND_OUT_ASSET_OR_NOTHING:
+        elif self._option_type == TouchOptionTypes.UP_AND_OUT_ASSET_OR_NOTHING:
             # HAUG 12
 
             if s0 >= H:
