@@ -92,6 +92,8 @@ class EquityOption:
              model):
         """ Calculation of option vega by perturbing vol and revaluation. """
 
+        bump = 0.01
+        
         v = self.value(valuation_date, stock_price, discount_curve,
                        dividend_curve, model)
 
@@ -100,9 +102,37 @@ class EquityOption:
         vBumped = self.value(valuation_date, stock_price, discount_curve,
                              dividend_curve, model)
 
-        vega = (vBumped - v) / bump
+        vega = (vBumped - v) # / bump
         return vega
 
+##############################################################################
+
+    def vanna(self,
+              valuation_date: Date,
+              stock_price: float,
+              discount_curve: DiscountCurve,
+              dividend_curve: DiscountCurve,
+              model):
+        """ Calculation of option vanna by perturbing delta with respect to the
+        stock price volatility. """
+
+        delta = self.delta(valuation_date,
+                           stock_price,
+                           discount_curve,
+                           dividend_curve,
+                           model)
+
+        model = BlackScholes(model._volatility + bump)
+
+        deltaBumped = self.delta(valuation_date,
+                                 stock_price,
+                                 discount_curve,
+                                 dividend_curve,
+                                 model)
+
+        vanna = (deltaBumped - delta) / bump
+        return vanna
+
 ###############################################################################
 
     def theta(self,
@@ -121,16 +151,19 @@ class EquityOption:
 
         next_date = valuation_date.add_days(1)
 
-        # Need to do this carefully.
-
+        # Need to do this carefully. This is a bit hacky.
         discount_curve._valuation_date = next_date
+        dividend_curve._valuation_date = next_date
         bump = (next_date - valuation_date) / gDaysInYear
 
         vBumped = self.value(next_date, stock_price,
                              discount_curve,
                              dividend_curve, model)
 
+        # restore valuation dates
         discount_curve._valuation_date = valuation_date
+        dividend_curve._valuation_date = valuation_date
+
         theta = (vBumped - v) / bump
         return theta
 
@@ -148,7 +181,9 @@ class EquityOption:
         v = self.value(valuation_date, stock_price, discount_curve,
                        dividend_curve, model)
 
-        vBumped = self.value(valuation_date, stock_price, discount_curve.bump(bump),
+        vBumped = self.value(valuation_date,
+                             stock_price,
+                             discount_curve.bump(bump),
                              dividend_curve, model)
 
         rho = (vBumped - v) / bump
