@@ -10,7 +10,7 @@ from ...utils.math import N
 from ...utils.global_vars import gDaysInYear, gSmall
 from ...utils.error import FinError
 from ...models.gbm_process_simulator import FinGBMProcess
-from ...utils.helpers import label_to_string, check_argument_types
+from ...utils.helpers import check_argument_types
 from ...utils.date import Date
 from ...utils.global_types import OptionTypes
 from ...market.curves.discount_curve import DiscountCurve
@@ -49,19 +49,33 @@ class FXFixedLookbackOption:
     def value(self,
               valuation_date: Date,
               stock_price: float,
-              domestic_curve: DiscountCurve,
-              foreign_curve: DiscountCurve,
+              dom_discount_curve: DiscountCurve,
+              for_discount_curve: DiscountCurve,
               volatility: float,
               stock_min_max: float):
         """ Value FX Fixed Lookback Option using Black Scholes model and
         analytical formulae. """
 
+        if isinstance(valuation_date, Date) == False:
+            raise FinError("Valuation date is not a Date")
+
+        if valuation_date > self._expiry_date:
+            raise FinError("Valuation date after expiry date.")
+
+        if dom_discount_curve._valuation_date != valuation_date:
+            raise FinError(
+                "Domestic Curve valuation date not same as option valuation date")
+
+        if for_discount_curve._valuation_date != valuation_date:
+            raise FinError(
+                "Foreign Curve valuation date not same as option valuation date")
+
         t = (self._expiry_date - valuation_date) / gDaysInYear
 
-        df = domestic_curve.df(self._expiry_date)
+        df = dom_discount_curve.df(self._expiry_date)
         r = -np.log(df)/t
 
-        dq = foreign_curve.df(self._expiry_date)
+        dq = for_discount_curve.df(self._expiry_date)
         q = -np.log(dq)/t
 
         v = volatility
@@ -120,7 +134,7 @@ class FXFixedLookbackOption:
                     term = expbt * N(e1)
                 else:
                     term = (-(s0 / smax)**(-w)) * \
-                           N(e1 - 2.0 * b * sqrt(t) / v) + expbt * N(e1)
+                        N(e1 - 2.0 * b * sqrt(t) / v) + expbt * N(e1)
 
                 v = df * (smax - k) + s0 * dq * N(e1) - \
                     smax * df * N(e2) + s0 * df * u * term
@@ -164,15 +178,15 @@ class FXFixedLookbackOption:
 ###############################################################################
 
     def value_mc(self,
-                valuation_date: Date,
-                spot_fx_rate: float,  # FORDOM
-                domestic_curve: DiscountCurve,
-                foreign_curve: DiscountCurve,
-                volatility: float,
-                spot_fx_rateMinMax: float,
-                num_paths:int = 10000,
-                num_steps_per_year: int =252,
-                seed: int =4242):
+                 valuation_date: Date,
+                 spot_fx_rate: float,  # FORDOM
+                 domestic_curve: DiscountCurve,
+                 foreign_curve: DiscountCurve,
+                 volatility: float,
+                 spot_fx_rateMinMax: float,
+                 num_paths: int = 10000,
+                 num_steps_per_year: int = 252,
+                 seed: int = 4242):
         """ Value FX Fixed Lookback option using Monte Carlo. """
 
         t = (self._expiry_date - valuation_date) / gDaysInYear
