@@ -48,7 +48,7 @@ def _f(df, *args):
 
 
 def _g(df, *args):
-    """ Root search objective function for swaps """
+    """ Root search objective function for FRAs """
     curve = args[0]
     valuation_date = args[1]
     fra = args[2]
@@ -351,7 +351,12 @@ class IborSingleCurve(DiscountCurve):
         self._usedDeposits = ibor_deposits
         self._usedFRAs = ibor_fras
         self._usedSwaps = ibor_swaps
-        self._day_count_type = None
+
+      # Need the floating leg basis for the curve
+        if len(self._usedSwaps) > 0:
+            self._day_count_type = ibor_swaps[0]._float_leg._day_count_type
+        else:
+            self._day_count_type = None
 
 ###############################################################################
 
