@@ -95,7 +95,7 @@ class Calendar:
                 "Need to pass FinCalendarType and not " +
                 str(calendar_type))
 
-        self._type = calendar_type
+        self._calendar_type = calendar_type
 
     ###########################################################################
 
@@ -108,6 +108,10 @@ class Calendar:
         if type(busDayConventionType) != BusDayAdjustTypes:
             raise FinError("Invalid type passed. Need FinBusDayConventionType")
 
+        # If calendar type is NONE then every day is a business day 
+        if self._calendar_type == CalendarTypes.NONE:
+            return dt
+
         if busDayConventionType == BusDayAdjustTypes.NONE:
             return dt
 
@@ -178,8 +182,8 @@ class Calendar:
 ###############################################################################
 
     def add_business_days(self,
-                        start_date: Date,
-                        numDays: int):
+                          start_date: Date,
+                          numDays: int):
         """ Returns a new date that is numDays business days after Date.
         All holidays in the chosen calendar are assumed not business days. """
 
@@ -214,7 +218,7 @@ class Calendar:
 ###############################################################################
 
     def is_business_day(self,
-                      dt: Date):
+                        dt: Date):
         """ Determines if a date is a business day according to the specified
         calendar. If it is it returns True, otherwise False. """
 
@@ -231,7 +235,7 @@ class Calendar:
 ###############################################################################
 
     def is_holiday(self,
-                  dt: Date):
+                   dt: Date):
         """ Determines if a date is a Holiday according to the specified
         calendar. Weekends are not holidays unless the holiday falls on a 
         weekend date. """
@@ -247,38 +251,38 @@ class Calendar:
         self._weekday = weekday
         self._dt = dt
 
-        if self._type == CalendarTypes.NONE:
+        if self._calendar_type == CalendarTypes.NONE:
             return self.holiday_none()
-        elif self._type == CalendarTypes.WEEKEND:
+        elif self._calendar_type == CalendarTypes.WEEKEND:
             return self.holiday_weekend()
-        elif self._type == CalendarTypes.AUSTRALIA:
+        elif self._calendar_type == CalendarTypes.AUSTRALIA:
             return self.holiday_australia()
-        elif self._type == CalendarTypes.CANADA:
+        elif self._calendar_type == CalendarTypes.CANADA:
             return self.holiday_canada()
-        elif self._type == CalendarTypes.FRANCE:
+        elif self._calendar_type == CalendarTypes.FRANCE:
             return self.holiday_france()
-        elif self._type == CalendarTypes.GERMANY:
+        elif self._calendar_type == CalendarTypes.GERMANY:
             return self.holiday_germany()
-        elif self._type == CalendarTypes.ITALY:
+        elif self._calendar_type == CalendarTypes.ITALY:
             return self.holiday_italy()
-        elif self._type == CalendarTypes.JAPAN:
+        elif self._calendar_type == CalendarTypes.JAPAN:
             return self.holiday_japan()
-        elif self._type == CalendarTypes.NEW_ZEALAND:
+        elif self._calendar_type == CalendarTypes.NEW_ZEALAND:
             return self.holiday_new_zealand()
-        elif self._type == CalendarTypes.NORWAY:
+        elif self._calendar_type == CalendarTypes.NORWAY:
             return self.holiday_norway()
-        elif self._type == CalendarTypes.SWEDEN:
+        elif self._calendar_type == CalendarTypes.SWEDEN:
             return self.holiday_sweden()
-        elif self._type == CalendarTypes.SWITZERLAND:
+        elif self._calendar_type == CalendarTypes.SWITZERLAND:
             return self.holiday_switzerland()
-        elif self._type == CalendarTypes.TARGET:
+        elif self._calendar_type == CalendarTypes.TARGET:
             return self.holiday_target()
-        elif self._type == CalendarTypes.UNITED_KINGDOM:
+        elif self._calendar_type == CalendarTypes.UNITED_KINGDOM:
             return self.holiday_united_kingdom()
-        elif self._type == CalendarTypes.UNITED_STATES:
+        elif self._calendar_type == CalendarTypes.UNITED_STATES:
             return self.holiday_united_states()
         else:
-            print(self._type)
+            print(self._calendar_type)
             raise FinError("Unknown calendar")
 
 ###############################################################################
@@ -296,7 +300,9 @@ class Calendar:
     def holiday_australia(self):
         """ Only bank holidays. Weekends by themselves are not a holiday. """
 
-        m = self._m; d = self._d; y = self._y
+        m = self._m
+        d = self._d
+        y = self._y
         day_in_year = self._day_in_year
         weekday = self._weekday
 
@@ -354,14 +360,17 @@ class Calendar:
             return True
 
         return False
-   
+
 ###############################################################################
 
     def holiday_united_kingdom(self):
         """ Only bank holidays. Weekends by themselves are not a holiday. """
 
-        m = self._m; d = self._d; y = self._y
-        weekday = self._weekday ; day_in_year = self._day_in_year
+        m = self._m
+        d = self._d
+        y = self._y
+        weekday = self._weekday
+        day_in_year = self._day_in_year
 
         if m == 1 and d == 1:  # new years day
             return True
@@ -386,10 +395,10 @@ class Calendar:
         if m == 5 and d >= 25 and weekday == Date.MON:
             return True
 
-        if m == 6 and d == 2 and y == 2022: # SPRING BANK HOLIDAY
+        if m == 6 and d == 2 and y == 2022:  # SPRING BANK HOLIDAY
             return True
 
-        if m == 6 and d == 3 and y == 2022: # QUEEN PLAT JUB
+        if m == 6 and d == 3 and y == 2022:  # QUEEN PLAT JUB
             return True
 
         if m == 8 and d > 24 and weekday == Date.MON:  # Late Summer
@@ -420,7 +429,9 @@ class Calendar:
     def holiday_france(self):
         """ Only bank holidays. Weekends by themselves are not a holiday. """
 
-        m = self._m; d = self._d; y = self._y
+        m = self._m
+        d = self._d
+        y = self._y
         day_in_year = self._day_in_year
 
         if m == 1 and d == 1:  # new years day
@@ -434,10 +445,10 @@ class Calendar:
         if day_in_year == em - 3:  # good friday
             return True
 
-        if m == 5 and d == 1: # LABOUR DAY
+        if m == 5 and d == 1:  # LABOUR DAY
             return True
 
-        if m == 5 and d == 8: # VICTORY DAY
+        if m == 5 and d == 8:  # VICTORY DAY
             return True
 
         if day_in_year == em + 39 - 1:  # Ascension
@@ -446,10 +457,10 @@ class Calendar:
         if day_in_year == em + 50 - 1:  # pentecost
             return True
 
-        if m == 7 and d == 14: # BASTILLE DAY
+        if m == 7 and d == 14:  # BASTILLE DAY
             return True
 
-        if m == 8 and d  == 15:  # ASSUMPTION
+        if m == 8 and d == 15:  # ASSUMPTION
             return True
 
         if m == 11 and d == 1:  # ALL SAINTS
@@ -471,7 +482,9 @@ class Calendar:
     def holiday_sweden(self):
         """ Only bank holidays. Weekends by themselves are not a holiday. """
 
-        m = self._m; d = self._d; y = self._y
+        m = self._m
+        d = self._d
+        y = self._y
         day_in_year = self._day_in_year
         weekday = self._weekday
 
@@ -495,10 +508,10 @@ class Calendar:
         if m == 5 and d == 1:  # labour day
             return True
 
-        if m == 6 and d == 6: # June
+        if m == 6 and d == 6:  # June
             return True
 
-        if m == 6 and d > 18 and d < 26 and weekday == Date.FRI: # Midsummer
+        if m == 6 and d > 18 and d < 26 and weekday == Date.FRI:  # Midsummer
             return True
 
         if m == 12 and d == 24:  # Xmas eve
@@ -520,7 +533,9 @@ class Calendar:
     def holiday_germany(self):
         """ Only bank holidays. Weekends by themselves are not a holiday. """
 
-        m = self._m; d = self._d; y = self._y
+        m = self._m
+        d = self._d
+        y = self._y
         day_in_year = self._day_in_year
 
         if m == 1 and d == 1:  # new years day
@@ -534,7 +549,7 @@ class Calendar:
         if day_in_year == em - 3:  # good friday
             return True
 
-        if m == 5 and d == 1: # LABOUR DAY
+        if m == 5 and d == 1:  # LABOUR DAY
             return True
 
         if day_in_year == em + 39 - 1:  # Ascension
@@ -562,7 +577,9 @@ class Calendar:
     def holiday_switzerland(self):
         """ Only bank holidays. Weekends by themselves are not a holiday. """
 
-        m = self._m; d = self._d; y = self._y
+        m = self._m
+        d = self._d
+        y = self._y
         day_in_year = self._day_in_year
 
         if m == 1 and d == 1:  # new years day
@@ -604,7 +621,9 @@ class Calendar:
     def holiday_japan(self):
         """ Only bank holidays. Weekends by themselves are not a holiday. """
 
-        m = self._m; d = self._d; y = self._y;
+        m = self._m
+        d = self._d
+        y = self._y
         weekday = self._weekday
 
         if m == 1 and d == 1:  # new years day
@@ -658,10 +677,10 @@ class Calendar:
         if m == 7 and d > 14 and d < 22 and y != 2021 and weekday == Date.MON:
             return True
 
-        if m == 7 and d == 22 and y == 2021: # OLYMPICS
+        if m == 7 and d == 22 and y == 2021:  # OLYMPICS
             return True
 
-        if m == 7 and d == 23 and y == 2021: # OLYMPICS HEALTH AND SPORTS HERE
+        if m == 7 and d == 23 and y == 2021:  # OLYMPICS HEALTH AND SPORTS HERE
             return True
 
         # Mountain day
@@ -704,7 +723,9 @@ class Calendar:
     def holiday_new_zealand(self):
         """ Only bank holidays. Weekends by themselves are not a holiday. """
 
-        m = self._m; d = self._d; y = self._y
+        m = self._m
+        d = self._d
+        y = self._y
         day_in_year = self._day_in_year
         weekday = self._weekday
 
@@ -765,7 +786,9 @@ class Calendar:
     def holiday_norway(self):
         """ Only bank holidays. Weekends by themselves are not a holiday. """
 
-        m = self._m; d = self._d; y = self._y
+        m = self._m
+        d = self._d
+        y = self._y
         day_in_year = self._day_in_year
 
         if m == 1 and d == 1:  # new years day
@@ -810,7 +833,8 @@ class Calendar:
         holidays for bond markets, NYSE, and public holidays. For each of
         these and other categories there will be some variations. """
 
-        m = self._m; d = self._d; 
+        m = self._m
+        d = self._d
         weekday = self._weekday
 
         if m == 1 and d == 1:  # NYD
@@ -877,8 +901,11 @@ class Calendar:
     def holiday_canada(self):
         """ Only bank holidays. Weekends by themselves are not a holiday. """
 
-        m = self._m; d = self._d; y = self._y
-        weekday = self._weekday; day_in_year = self._day_in_year
+        m = self._m
+        d = self._d
+        y = self._y
+        weekday = self._weekday
+        day_in_year = self._day_in_year
 
         if m == 1 and d == 1:  # NYD
             return True
@@ -952,7 +979,9 @@ class Calendar:
     def holiday_italy(self):
         """ Only bank holidays. Weekends by themselves are not a holiday. """
 
-        m = self._m; d = self._d; y = self._y
+        m = self._m
+        d = self._d
+        y = self._y
         day_in_year = self._day_in_year
 
         if m == 1 and d == 1:  # new years day
@@ -969,16 +998,16 @@ class Calendar:
         if day_in_year == em - 3:  # good friday
             return True
 
-        if m == 4 and d == 25: # LIBERATION DAY
+        if m == 4 and d == 25:  # LIBERATION DAY
             return True
 
-        if m == 5 and d == 1: # LABOUR DAY
+        if m == 5 and d == 1:  # LABOUR DAY
             return True
 
-        if m == 6 and d == 2 and y > 1999: # REPUBLIC DAY
+        if m == 6 and d == 2 and y > 1999:  # REPUBLIC DAY
             return True
 
-        if m == 8 and d  == 15:  # ASSUMPTION
+        if m == 8 and d == 15:  # ASSUMPTION
             return True
 
         if m == 11 and d == 1:  # ALL SAINTS
@@ -1000,7 +1029,9 @@ class Calendar:
     def holiday_target(self):
         """ Only bank holidays. Weekends by themselves are not a holiday. """
 
-        m = self._m; d = self._d; y = self._y
+        m = self._m
+        d = self._d
+        y = self._y
         day_in_year = self._day_in_year
 
         if m == 1 and d == 1:  # new year's day
@@ -1042,7 +1073,7 @@ class Calendar:
         holidayList = []
         while start_date < end_date:
             if self.is_business_day(start_date) is False and \
-              start_date.is_weekend() is False:
+                    start_date.is_weekend() is False:
                 holidayList.append(start_date.__str__())
 
             start_date = start_date.add_days(1)
@@ -1068,13 +1099,13 @@ class Calendar:
 ###############################################################################
 
     def __str__(self):
-        s = self._type.name
+        s = self._calendar_type.name
         return s
 
 ###############################################################################
 
     def __repr__(self):
-        s = self._type
+        s = self._calendar_type
         return s
 
 ###############################################################################
