@@ -5,6 +5,7 @@
 from numba import njit
 import numpy as np
 import datetime
+import math
 
 from financepy.utils.error import FinError
 
@@ -295,6 +296,16 @@ class Date():
 
     ###########################################################################
 
+    @classmethod
+    def from_date(cls, date: datetime.date):
+        """  Create a Date from a python datetime.date object.
+        Example Input:
+        start_date = Date.from_date(datetime.date(2022, 11, 8)) """
+
+        d, m, y = date.day, date.month, date.year
+        return cls(d, m, y)
+
+    ###########################################################################
     def _refresh(self):
         """ Update internal representation of date as number of days since the
         1st Jan 1900. This is same as Excel convention. """
@@ -437,6 +448,8 @@ class Date():
 
         # TODO: REMOVE DATETIME DEPENDENCE HERE
 
+        end_date = self
+
         if isinstance(numDays, int) is False:
             raise FinError("Num days must be an integer")
 
@@ -444,22 +457,51 @@ class Date():
         numDays = abs(numDays)
 
         # 5 week days make up a week
-        numWeeks = int(numDays / 5)
-        remainingDays = numDays % 5
+        oldLogic = False
 
-        if (positiveNumDays):
-            if (self._weekday + remainingDays > self.FRI):
-                # add weekend
-                remainingDays += 2
+        if oldLogic is True:
+            numWeeks = int(numDays / 5)
+            remainingDays = numDays % 5
 
-            return self.add_days(numWeeks * 7 + remainingDays)
-        else:
-            if (self._weekday - remainingDays < self.MON):
-                # add weekend
-                remainingDays += 2
+            if self._weekday == Date.SAT:
+                weekendAdjust = 1
+            elif self._weekday == Date.SUN:
+                weekendAdjust = 0
+            else:
+                weekendAdjust = 2
+
+            if (positiveNumDays):
+                if (self._weekday + remainingDays > self.FRI):
+                    # add weekend
+                    remainingDays += weekendAdjust
+
+                return self.add_days(numWeeks * 7 + remainingDays)
+            else:
+                if (self._weekday - remainingDays < self.MON):
+                    # add weekend
+                    remainingDays += weekendAdjust
 
             return self.add_days(-(numWeeks * 7 + remainingDays))
 
+        else:  # new logic
+
+            numDaysLeft = numDays
+            end_date = self
+
+            while numDaysLeft > 0:
+
+                if positiveNumDays is True:
+                    end_date = end_date.add_days(1)
+                else:
+                    end_date = end_date.add_days(-1)
+
+                if end_date._weekday == Date.SAT or end_date._weekday == Date.SUN:
+                    pass
+                else:
+                    numDaysLeft -= 1
+
+            return end_date
+
     ###########################################################################
 
     def add_months(self,
@@ -686,6 +728,7 @@ class Date():
         newDates = []
 
         for tenStr in tenor:
+
             tenStr = tenStr.upper()
             DAYS = 1
             WEEKS = 2
@@ -719,17 +762,24 @@ class Date():
             newDate = Date(self._d, self._m, self._y)
 
             if periodType == DAYS:
-                for _ in range(0, num_periods):
-                    newDate = newDate.add_days(1)
+                for _ in range(0, abs(num_periods)):
+                    newDate = newDate.add_days(math.copysign(1, num_periods))
             elif periodType == WEEKS:
-                for _ in range(0, num_periods):
-                    newDate = newDate.add_days(7)
+                for _ in range(0, abs(num_periods)):
+                    newDate = newDate.add_days(math.copysign(7, num_periods))
             elif periodType == MONTHS:
-                for _ in range(0, num_periods):
-                    newDate = newDate.add_months(1)
+                for _ in range(0, abs(num_periods)):
+                    newDate = newDate.add_months(math.copysign(1, num_periods))
+
+                # in case we landed on a 28th Feb and lost the month day we add this logic
+                y = newDate._y
+                m = newDate._m
+                d = min(self._d, newDate.eom()._d)
+                newDate = Date(d, m, y)
+
             elif periodType == YEARS:
-                for _ in range(0, num_periods):
-                    newDate = newDate.add_months(12)
+                for _ in range(0, abs(num_periods)):
+                    newDate = newDate.add_months(math.copysign(12, num_periods))
 
             newDates.append(newDate)
 
