@@ -2,6 +2,7 @@ from __future__ import print_function, division
 
 __author__ = 'saeedamen'  # Saeed Amen / saeed@cuemacro.com
 
+
 class Singleton(type):
     """Singleton type which is used to ensure there is only one instance across the whole project.
 
@@ -10,5 +11,6 @@ class Singleton(type):
 
     def __call__(cls, *args, **kwargs):
         if cls not in cls._instances.keys():
-            cls._instances[cls] = super(Singleton, cls).__call__(*args, **kwargs)
+            cls._instances[cls] = super(
+                Singleton, cls).__call__(*args, **kwargs)
         return cls._instances[cls]
