@@ -2,6 +2,9 @@
 # Copyright (C) 2018, 2019, 2020 Dominic O'Kane
 ##############################################################################
 
+import sys
+sys.path.append("..")
+
 from FinTestCases import FinTestCases, globalTestCaseMode
 from financepy.market.curves.discount_curve_flat import DiscountCurveFlat
 from financepy.utils.calendar import CalendarTypes
@@ -12,15 +15,12 @@ from financepy.utils.math import ONE_MILLION
 from financepy.products.rates.ibor_swap import IborSwap
 from financepy.products.rates.ibor_deposit import IborDeposit
 from financepy.products.rates.ibor_single_curve import IborSingleCurve
-from financepy.products.bonds.bond import Bond
-from financepy.products.bonds.bond import YTMCalcType
+from financepy.products.bonds.bond import YTMCalcType, Bond
 from financepy.utils.global_types import SwapTypes
 import os
 import datetime as dt
+import pandas as pd
 
-import sys
-
-sys.path.append("..")
 
 
 testCases = FinTestCases(__file__, globalTestCaseMode)
@@ -234,7 +234,8 @@ def test_Bond():
     face = ONE_MILLION
 
     for accrual_type in DayCountTypes:
-
+        if accrual_type == DayCountTypes.ZERO:
+            continue
         testCases.header("MATURITY", "COUPON", "CLEAN_PRICE", "ACCD_DAYS",
                          "ACCRUED", "YTM")
 
@@ -356,18 +357,19 @@ def test_Bond():
     coupon = 0.02375
     freq_type = FrequencyTypes.SEMI_ANNUAL
     accrual_type = DayCountTypes.ACT_ACT_ICMA
-    face = 100.0
+    face = 1000000.0
 
     bond = Bond(issue_date,
                 maturity_date,
                 coupon,
                 freq_type,
                 accrual_type,
-                face)
+                face, 
+                CalendarTypes.UNITED_STATES)
 
     testCases.header("FIELD", "VALUE")
     clean_price = 99.7808417
-
+        
     yld = bond.current_yield(clean_price)
     testCases.print("Current Yield = ", yld)
 
@@ -383,10 +385,12 @@ def test_Bond():
                                  YTMCalcType.US_TREASURY)
     testCases.print("US TREASURY Yield To Maturity = ", ytm)
 
-    full_price = bond.full_price_from_ytm(settlement_date, ytm)
+    full_price = bond.full_price_from_ytm(settlement_date, ytm, 
+                                          YTMCalcType.US_TREASURY)
     testCases.print("Full Price = ", full_price)
 
-    clean_price = bond.clean_price_from_ytm(settlement_date, ytm)
+    clean_price = bond.clean_price_from_ytm(settlement_date, ytm,
+                                            YTMCalcType.US_TREASURY)
     testCases.print("Clean Price = ", clean_price)
 
     accrued_interest = bond._accrued_interest
@@ -395,9 +399,9 @@ def test_Bond():
     accddays = bond._accrued_days
     testCases.print("Accrued Days = ", accddays)
 
-    duration = bond.dollar_duration(settlement_date, ytm)
+    duration = bond.dollar_duration(settlement_date, ytm, YTMCalcType.US_STREET) 
     testCases.print("Dollar Duration = ", duration)
-
+    
     modified_duration = bond.modified_duration(settlement_date, ytm)
     testCases.print("Modified Duration = ", modified_duration)
 
@@ -512,10 +516,54 @@ def test_BondExDividend():
             settlement_date, exDivDays, calendar_type)
         testCases.print(settlement_date, accrued)
 
+###############################################################################
+
+def test_BondPaymentDates():
+    from financepy.products.bonds.bond import Bond
+    from financepy.utils import Date, DayCountTypes, FrequencyTypes
+    
+    bond = Bond(
+            issue_date=Date(7, 6, 2021),
+            maturity_date=Date(7, 6, 2031),
+            coupon=0.0341,
+            freq_type=FrequencyTypes.ANNUAL,
+            accrual_type=DayCountTypes.ACT_ACT_ISDA
+    )
+    bond._calculate_payment_dates()
+
+    if 1==0:
+        print(bond._flow_amounts)
+        print(bond._coupon_dates)
+        print(bond._payment_dates)
 
 ###############################################################################
 
+def test_Bond_ror():
+    test_case_file = 'test_cases_bond_ror.csv'
+    df = pd.read_csv('./data/' + test_case_file, parse_dates=['buy_date', 'sell_date'])
+    # A 10-year bond with 1 coupon per year. code: 210215
+    bond = Bond(
+        issue_date=Date(13, 9, 2021),
+        maturity_date=Date(13, 9, 2031),
+        coupon=0.0312,
+        freq_type=FrequencyTypes.ANNUAL,
+        accrual_type=DayCountTypes.ACT_ACT_ICMA
+    )
+    testCases.header('bond_code', 'buy_date', 'buy_ytm', 'buy_price', 'sell_date', 'sell_ytm', 'sell_price',
+                     'simple_return', 'irr')
+    for row in df.itertuples(index=False):
+        buy_date = Date(row.buy_date.day, row.buy_date.month, row.buy_date.year)
+        sell_date = Date(row.sell_date.day, row.sell_date.month, row.sell_date.year)
+        buy_price = bond.full_price_from_ytm(buy_date, row.buy_ytm, YTMCalcType.US_STREET)
+        sell_price = bond.full_price_from_ytm(sell_date, row.sell_ytm, YTMCalcType.US_STREET)
+        simple, irr, pnl = bond.calc_ror(buy_date, sell_date, row.buy_ytm, row.sell_ytm)
+        testCases.print(row.bond_code, buy_date, row.buy_ytm, buy_price, sell_date, row.sell_ytm, sell_price,
+                        simple, irr)
+
 
 test_Bond()
 test_BondExDividend()
+test_BondPaymentDates()
+test_Bond_ror()
+
 testCases.compareTestCases()
