@@ -3,19 +3,19 @@
 ###############################################################################
 
 # TODO Set up test cases correctly
-
 import sys
 sys.path.append("..")
 
-from financepy.utils.calendar import DateGenRuleTypes
-from financepy.utils.calendar import BusDayAdjustTypes
-from financepy.utils.day_count import DayCountTypes
-from financepy.utils.calendar import CalendarTypes
-from financepy.utils.frequency import FrequencyTypes
-from financepy.utils.date import Date
-from financepy.products.bonds.bond_annuity import BondAnnuity
-
 from FinTestCases import FinTestCases, globalTestCaseMode
+from financepy.products.bonds.bond_annuity import BondAnnuity
+from financepy.utils.date import Date
+from financepy.utils.frequency import FrequencyTypes
+from financepy.utils.calendar import CalendarTypes
+from financepy.utils.day_count import DayCountTypes
+from financepy.utils.calendar import BusDayAdjustTypes
+from financepy.utils.calendar import DateGenRuleTypes
+
+
 testCases = FinTestCases(__file__, globalTestCaseMode)
 
 ###############################################################################
@@ -50,9 +50,9 @@ def test_BondAnnuity():
     annuity.calculate_payments(settlement_date)
 
     testCases.header("Date", "Flow")
-    num_flows = len(annuity._flow_dates)
+    num_flows = len(annuity._coupon_dates)
     for i in range(1, num_flows):
-        dt = annuity._flow_dates[i]
+        dt = annuity._coupon_dates[i]
         flow = annuity._flow_amounts[i]
         testCases.print(dt, flow)
 
@@ -81,9 +81,9 @@ def test_BondAnnuity():
     annuity.calculate_payments(settlement_date)
 
     testCases.header("Date", "Flow")
-    num_flows = len(annuity._flow_dates)
+    num_flows = len(annuity._coupon_dates)
     for i in range(1, num_flows):
-        dt = annuity._flow_dates[i]
+        dt = annuity._coupon_dates[i]
         flow = annuity._flow_amounts[i]
         testCases.print(dt, flow)
 
@@ -111,9 +111,9 @@ def test_BondAnnuity():
     annuity.calculate_payments(settlement_date)
 
     testCases.header("Date", "Flow")
-    num_flows = len(annuity._flow_dates)
+    num_flows = len(annuity._coupon_dates)
     for i in range(1, num_flows):
-        dt = annuity._flow_dates[i]
+        dt = annuity._coupon_dates[i]
         flow = annuity._flow_amounts[i]
         testCases.print(dt, flow)
 
@@ -141,9 +141,9 @@ def test_BondAnnuity():
     annuity.calculate_payments(settlement_date)
 
     testCases.header("Date", "Flow")
-    num_flows = len(annuity._flow_dates)
+    num_flows = len(annuity._coupon_dates)
     for i in range(1, num_flows):
-        dt = annuity._flow_dates[i]
+        dt = annuity._coupon_dates[i]
         flow = annuity._flow_amounts[i]
         testCases.print(dt, flow)
 
@@ -160,7 +160,7 @@ def test_BondAnnuity():
     basis_type = DayCountTypes.ACT_360
 
     annuity = BondAnnuity(maturity_date,
-                          coupon, 
+                          coupon,
                           freq_type,
                           calendar_type,
                           bus_day_adjust_type,
@@ -171,9 +171,9 @@ def test_BondAnnuity():
     annuity.calculate_payments(settlement_date)
 
     testCases.header("Date", "Flow")
-    num_flows = len(annuity._flow_dates)
+    num_flows = len(annuity._coupon_dates)
     for i in range(1, num_flows):
-        dt = annuity._flow_dates[i]
+        dt = annuity._coupon_dates[i]
         flow = annuity._flow_amounts[i]
         testCases.print(dt, flow)
 
@@ -197,13 +197,13 @@ def test_BondAnnuity():
                           date_gen_rule_type,
                           basis_type,
                           face)
-    
+
     annuity.calculate_payments(settlement_date)
 
     testCases.header("Date", "Flow")
-    num_flows = len(annuity._flow_dates)
+    num_flows = len(annuity._coupon_dates)
     for i in range(1, num_flows):
-        dt = annuity._flow_dates[i]
+        dt = annuity._coupon_dates[i]
         flow = annuity._flow_amounts[i]
         testCases.print(dt, flow)
 
