@@ -2,25 +2,25 @@
 # Copyright (C) 2018, 2019, 2020 Dominic O'Kane
 ###############################################################################
 
-import matplotlib.pyplot as plt
-import time
-
 import sys
 sys.path.append("..")
 
-from financepy.utils.global_types import SwapTypes
-from financepy.utils.date import Date
-from financepy.utils.frequency import FrequencyTypes
-from financepy.utils.day_count import DayCountTypes
-from financepy.models.hw_tree import HWTree
-
-from financepy.products.rates.ibor_swap import IborSwap
-from financepy.products.rates.ibor_single_curve import IborSingleCurve
-from financepy.market.curves.discount_curve_flat import DiscountCurveFlat
-from financepy.products.bonds.bond import Bond
-from financepy.products.bonds.bond_callable import BondEmbeddedOption
-
 from FinTestCases import FinTestCases, globalTestCaseMode
+from financepy.products.bonds.bond_callable import BondEmbeddedOption
+from financepy.products.bonds.bond import Bond
+from financepy.market.curves.discount_curve_flat import DiscountCurveFlat
+from financepy.products.rates.ibor_single_curve import IborSingleCurve
+from financepy.products.rates.ibor_swap import IborSwap
+from financepy.models.hw_tree import HWTree
+from financepy.utils.day_count import DayCountTypes
+from financepy.utils.frequency import FrequencyTypes
+from financepy.utils.date import Date
+from financepy.utils.global_types import SwapTypes
+import matplotlib.pyplot as plt
+import time
+
+
+
 testCases = FinTestCases(__file__, globalTestCaseMode)
 
 plotGraphs = False
@@ -37,15 +37,18 @@ def test_BondEmbeddedOptionMATLAB():
 
     settlement_date = Date(1, 1, 2007)
     valuation_date = settlement_date
-    
+
     ###########################################################################
 
     dcType = DayCountTypes.THIRTY_E_360
     fixedFreq = FrequencyTypes.ANNUAL
     fixed_leg_type = SwapTypes.PAY
-    swap1 = IborSwap(settlement_date, "1Y", fixed_leg_type, 0.0350, fixedFreq, dcType)
-    swap2 = IborSwap(settlement_date, "2Y", fixed_leg_type, 0.0400, fixedFreq, dcType)
-    swap3 = IborSwap(settlement_date, "3Y", fixed_leg_type, 0.0450, fixedFreq, dcType)
+    swap1 = IborSwap(settlement_date, "1Y", fixed_leg_type,
+                     0.0350, fixedFreq, dcType)
+    swap2 = IborSwap(settlement_date, "2Y", fixed_leg_type,
+                     0.0400, fixedFreq, dcType)
+    swap3 = IborSwap(settlement_date, "3Y", fixed_leg_type,
+                     0.0450, fixedFreq, dcType)
     swaps = [swap1, swap2, swap3]
     discount_curve = IborSingleCurve(valuation_date, [], [], swaps)
 
@@ -53,7 +56,7 @@ def test_BondEmbeddedOptionMATLAB():
 
     issue_date = Date(1, 1, 2004)
     maturity_date = Date(1, 1, 2010)
-    
+
     coupon = 0.0525
     freq_type = FrequencyTypes.ANNUAL
     accrual_type = DayCountTypes.ACT_ACT_ICMA
@@ -85,7 +88,7 @@ def test_BondEmbeddedOptionMATLAB():
 
     testCases.header("TIME", "NumTimeSteps", "BondWithOption", "BondPure")
 
-    timeSteps = range(50, 1000, 10)
+    timeSteps = range(50, 1000, 50)
     values = []
     for num_time_steps in timeSteps:
         model = HWTree(sigma, a, num_time_steps)
@@ -160,7 +163,7 @@ def test_BondEmbeddedOptionQUANTLIB():
     testCases.print("Bond Pure Price:", v)
 
     testCases.header("TIME", "NumTimeSteps", "BondWithOption", "BondPure")
-    timeSteps = range(100, 1000, 100)
+    timeSteps = range(100, 200, 50)
     values = []
     for num_time_steps in timeSteps:
         model = HWTree(sigma, a, num_time_steps)
@@ -168,7 +171,8 @@ def test_BondEmbeddedOptionQUANTLIB():
         v = puttableBond.value(settlement_date, discount_curve, model)
         end = time.time()
         period = end - start
-        testCases.print(period, num_time_steps, v['bondwithoption'], v['bondpure'])
+        testCases.print(period, num_time_steps,
+                        v['bondwithoption'], v['bondpure'])
         values.append(v['bondwithoption'])
 
     if plotGraphs:
