@@ -2,27 +2,24 @@
 # Copyright (C) 2018, 2019, 2020 Dominic O'Kane
 ###############################################################################
 
+import matplotlib.pyplot as plt
+import time
+import numpy as np
+from financepy.utils.global_types import FinExerciseTypes
+from financepy.utils.global_vars import gDaysInYear
+from financepy.utils.date import Date
+from financepy.market.curves.discount_curve import DiscountCurve
+from financepy.market.curves.discount_curve_flat import DiscountCurveFlat
+from financepy.products.bonds.bond import Bond
+from financepy.utils.frequency import FrequencyTypes
+from financepy.utils.day_count import DayCountTypes
+from financepy.products.bonds.bond_option import BondOption
+from financepy.utils.global_types import OptionTypes
+from financepy.models.hw_tree import HWTree, FinHWEuropeanCalcType
+from FinTestCases import FinTestCases, globalTestCaseMode
 import sys
 sys.path.append("..\\")
 
-from FinTestCases import FinTestCases, globalTestCaseMode
-from financepy.models.hw_tree import HWTree, FinHWEuropeanCalcType
-from financepy.utils.global_types import OptionTypes
-from financepy.products.bonds.bond_option import BondOption
-from financepy.utils.day_count import DayCountTypes
-from financepy.utils.frequency import FrequencyTypes
-from financepy.products.bonds.bond import Bond
-from financepy.market.curves.discount_curve_flat import DiscountCurveFlat
-from financepy.market.curves.discount_curve import DiscountCurve
-from financepy.utils.date import Date
-from financepy.utils.global_vars import gDaysInYear
-from financepy.utils.global_types import FinExerciseTypes
-
-import numpy as np
-import time
-import matplotlib.pyplot as plt
-
-
 
 testCases = FinTestCases(__file__, globalTestCaseMode)
 
@@ -52,7 +49,7 @@ def test_BondOption():
 
     ###########################################################################
 
-    strikes = [80, 85, 90, 95, 100, 105, 110, 115, 120]
+    strikes = [80, 90, 100, 110, 120]
 
     option_type = OptionTypes.EUROPEAN_CALL
 
@@ -62,7 +59,7 @@ def test_BondOption():
         settlement_date, discount_curve)
     testCases.print("Fixed Income Price:", price)
 
-    num_time_steps = 100
+    num_time_steps = 50
 
     testCases.banner("HW EUROPEAN CALL")
     testCases.header("STRIKE", "VALUE")
@@ -242,7 +239,7 @@ def test_BondOptionAmericanConvergenceONE():
     testCases.header("TIME", "N", "PUT_AMER", "PUT_EUR",
                      "CALL_AME", "CALL_EUR")
 
-    timeSteps = range(100, 500, 100)
+    timeSteps = range(100, 400, 100)
 
     for num_time_steps in timeSteps:
 
@@ -324,7 +321,7 @@ def test_BondOptionAmericanConvergenceTWO():
     vec_ep = []
     vec_ap = []
 
-    num_stepsVector = range(100, 500, 100)
+    num_stepsVector = range(100, 400, 100)
 
     for num_steps in num_stepsVector:
         hwModel = HWTree(sigma, a, num_steps)
@@ -412,8 +409,8 @@ def test_BondOptionZEROVOLConvergence():
                      "CALL_INT", "CALL_INT_PV", "CALL_EUR", "CALL_AMER",
                      "PUT_INT", "PUT_INT_PV", "PUT_EUR", "PUT_AMER")
 
-    num_time_steps = range(100, 1000, 100)
-    strike_prices = [90, 100, 110, 120]
+    num_time_steps = range(100, 400, 100)
+    strike_prices = [90, 120]
 
     for strike_price in strike_prices:
 
@@ -454,16 +451,18 @@ def test_BondOptionZEROVOLConvergence():
 
 ###############################################################################
 
+
 def test_BondOptionDerivaGem():
 
     # See https://github.com/domokane/FinancePy/issues/98
-    
+
     settlement_date = Date(1, 12, 2019)
 
     rate = 0.05
     dcType = DayCountTypes.THIRTY_360_BOND
     fixedFreq = FrequencyTypes.SEMI_ANNUAL
-    discount_curve = DiscountCurveFlat(settlement_date, rate, fixedFreq, dcType)
+    discount_curve = DiscountCurveFlat(
+        settlement_date, rate, fixedFreq, dcType)
 
     issue_date = Date(1, 12, 2018)
     expiry_date = settlement_date.add_tenor("18m")
@@ -476,14 +475,14 @@ def test_BondOptionDerivaGem():
     strike_price = 100.0
     face = 100.0
 
-    europeanCallBondOption = BondOption(bond, expiry_date, strike_price, face, 
+    europeanCallBondOption = BondOption(bond, expiry_date, strike_price, face,
                                         OptionTypes.EUROPEAN_CALL)
     cp = bond.clean_price_from_discount_curve(expiry_date, discount_curve)
     fp = bond.full_price_from_discount_curve(expiry_date, discount_curve)
 #    print("Fixed Income Clean Price: %9.3f"% cp)
 #    print("Fixed Income Full  Price: %9.3f"% fp)
 
-    num_steps= 500
+    num_steps = 500
     sigma = 0.0125
     a = 0.1
     modelHW = HWTree(sigma, a, num_steps)
@@ -496,19 +495,19 @@ def test_BondOptionDerivaGem():
     couponFlows = []
     cpn = bond._coupon/bond._frequency
 
-    numFlows = len(bond._flow_dates)
+    numFlows = len(bond._coupon_dates)
     for i in range(0, numFlows):
 
-        pcd = bond._flow_dates[i-1]
-        ncd = bond._flow_dates[i]
+        pcd = bond._coupon_dates[i-1]
+        ncd = bond._coupon_dates[i]
 
         if ncd > settlement_date:
-            
+
             if len(couponTimes) == 0:
                 flowTime = (pcd - settlement_date) / gDaysInYear
                 couponTimes.append(flowTime)
                 couponFlows.append(cpn)
-                
+
             flowTime = (ncd - settlement_date) / gDaysInYear
             couponTimes.append(flowTime)
             couponFlows.append(cpn)
@@ -533,7 +532,7 @@ def test_BondOptionDerivaGem():
                                                  couponTimes, couponFlows,
                                                  times, dfs)
     # print("Jamshidian:", vjam)
-    
+
     model._num_time_steps = 100
     model.build_tree(tmat, times, dfs)
     exerciseType = FinExerciseTypes.EUROPEAN
