@@ -3,7 +3,7 @@
 ###############################################################################
 
 import sys
-sys.path.append("..//")
+sys.path.append("..")
 
 import time
 import matplotlib.pyplot as plt
