@@ -2,15 +2,15 @@
 # Copyright (C) 2018, 2019, 2020 Dominic O'Kane
 ###############################################################################
 
-from FinTestCases import FinTestCases, globalTestCaseMode
-from financepy.utils.date import Date
-from financepy.models.black_scholes import BlackScholes
-from financepy.market.curves.discount_curve_flat import DiscountCurveFlat
-from financepy.products.equity.equity_one_touch_option import FinTouchOptionPayoffTypes
-from financepy.products.equity.equity_one_touch_option import EquityOneTouchOption
 import sys
 sys.path.append("..")
 
+from financepy.utils.global_types import TouchOptionTypes
+from financepy.products.fx import FXOneTouchOption
+from financepy.market.curves.discount_curve_flat import DiscountCurveFlat
+from financepy.models.black_scholes import BlackScholes
+from financepy.utils.date import Date
+from FinTestCases import FinTestCases, globalTestCaseMode
 
 testCases = FinTestCases(__file__, globalTestCaseMode)
 
@@ -30,8 +30,8 @@ def test_FinFXOneTouchOption():
     domesticRate = 0.10
     foreignRate = 0.03
 
-    num_paths = 20000
-    num_steps_per_year = 252
+    num_paths = 50000
+    num_steps_per_year = 252 * 2
 
     domCurve = DiscountCurveFlat(valuation_date, domesticRate)
     forCurve = DiscountCurveFlat(valuation_date, foreignRate)
@@ -41,18 +41,18 @@ def test_FinFXOneTouchOption():
 
     testCases.header("================================= CASH ONLY")
 
-    downTypes = [FinTouchOptionPayoffTypes.DOWN_AND_IN_CASH_AT_HIT,
-                 FinTouchOptionPayoffTypes.DOWN_AND_IN_CASH_AT_EXPIRY,
-                 FinTouchOptionPayoffTypes.DOWN_AND_OUT_CASH_OR_NOTHING]
+    downTypes = [TouchOptionTypes.DOWN_AND_IN_CASH_AT_HIT,
+                 TouchOptionTypes.DOWN_AND_IN_CASH_AT_EXPIRY,
+                 TouchOptionTypes.DOWN_AND_OUT_CASH_OR_NOTHING]
 
     testCases.header("TYPE", "VALUE", "VALUE_MC")
 
     for downType in downTypes:
 
-        option = EquityOneTouchOption(expiry_date,
-                                      downType,
-                                      barrier_level,
-                                      payment_size)
+        option = FXOneTouchOption(expiry_date,
+                                  downType,
+                                  barrier_level,
+                                  payment_size)
 
         v = option.value(valuation_date,
                          spot_fx_rate,
@@ -72,21 +72,23 @@ def test_FinFXOneTouchOption():
                         "%9.5f" % v,
                         "%9.5f" % v_mc)
 
+        print(downType, v, v_mc)
+
     spot_fx_rate = 0.950
     payment_size = 1.5
 
-    upTypes = [FinTouchOptionPayoffTypes.UP_AND_IN_CASH_AT_HIT,
-               FinTouchOptionPayoffTypes.UP_AND_IN_CASH_AT_EXPIRY,
-               FinTouchOptionPayoffTypes.UP_AND_OUT_CASH_OR_NOTHING]
+    upTypes = [TouchOptionTypes.UP_AND_IN_CASH_AT_HIT,
+               TouchOptionTypes.UP_AND_IN_CASH_AT_EXPIRY,
+               TouchOptionTypes.UP_AND_OUT_CASH_OR_NOTHING]
 
     testCases.header("TYPE", "VALUE", "VALUE_MC")
 
     for upType in upTypes:
 
-        option = EquityOneTouchOption(expiry_date,
-                                      upType,
-                                      barrier_level,
-                                      payment_size)
+        option = FXOneTouchOption(expiry_date,
+                                  upType,
+                                  barrier_level,
+                                  payment_size)
 
         v = option.value(valuation_date,
                          spot_fx_rate,
@@ -106,73 +108,89 @@ def test_FinFXOneTouchOption():
                         "%9.5f" % v,
                         "%9.5f" % v_mc)
 
-    ###########################################################################
+        print(upType, v, v_mc)
 
-    spot_fx_rate = 1.050
 
-    testCases.banner("================= ASSET ONLY")
+###############################################################################
 
-    downTypes = [FinTouchOptionPayoffTypes.DOWN_AND_IN_ASSET_AT_HIT,
-                 FinTouchOptionPayoffTypes.DOWN_AND_IN_ASSET_AT_EXPIRY,
-                 FinTouchOptionPayoffTypes.DOWN_AND_OUT_ASSET_OR_NOTHING]
+def test_BBGOneTouchOption():
 
-    testCases.header("TYPE", "VALUE", "VALUE_MC")
-    for downType in downTypes:
+    # 1YR ONETOUCH ON EURUSD 
 
-        option = EquityOneTouchOption(expiry_date,
-                                      downType,
-                                      barrier_level)
+    valuation_date = Date(3, 12, 2021)
+    expiry_date = Date(5, 12, 2022)
+    barrier_level = 1.1865  # THIS IS NUMBER OF DOLLARS PER EURO
 
-        v = option.value(valuation_date,
-                         spot_fx_rate,
-                         domCurve,
-                         forCurve,
-                         model)
+    spot_fx_rate = 1.1300 # EURUSD
+    volatility = 0.06075
 
-        v_mc = option.value_mc(valuation_date,
-                               spot_fx_rate,
-                               domCurve,
-                               forCurve,
-                               model,
-                               num_steps_per_year,
-                               num_paths)
+    model = BlackScholes(volatility)
 
-        testCases.print("%60s " % downType,
-                        "%9.5f" % v,
-                        "%9.5f" % v_mc)
+    forRate = 0.00593 # EUR
+    domRate = -0.00414 # USD
 
-    spot_fx_rate = 0.950
+    num_paths = 50000
+    num_steps_per_year = 252
 
-    upTypes = [FinTouchOptionPayoffTypes.UP_AND_IN_ASSET_AT_HIT,
-               FinTouchOptionPayoffTypes.UP_AND_IN_ASSET_AT_EXPIRY,
-               FinTouchOptionPayoffTypes.UP_AND_OUT_ASSET_OR_NOTHING]
+    domCurve = DiscountCurveFlat(valuation_date, domRate)
+    forCurve = DiscountCurveFlat(valuation_date, forRate)
 
-    for upType in upTypes:
+    payment_size = 1000000 # EUR
 
-        option = EquityOneTouchOption(expiry_date,
-                                      upType,
-                                      barrier_level)
+    optionType = TouchOptionTypes.UP_AND_IN_CASH_AT_EXPIRY
 
-        v = option.value(valuation_date,
-                         spot_fx_rate,
-                         domCurve,
-                         forCurve,
-                         model)
+    option = FXOneTouchOption(expiry_date,
+                              optionType,
+                              barrier_level,
+                              payment_size)
 
-        v_mc = option.value_mc(valuation_date,
-                               spot_fx_rate,
-                               domCurve,
-                               forCurve,
-                               model,
-                               num_steps_per_year,
-                               num_paths)
+    v = option.value(valuation_date,
+                     spot_fx_rate,
+                     domCurve,
+                     forCurve,
+                     model)
 
-        testCases.print("%60s " % upType,
-                        "%9.5f" % v,
-                        "%9.5f" % v_mc)
+    v_mc = option.value_mc(valuation_date,
+                           spot_fx_rate,
+                           domCurve,
+                           forCurve,
+                           model,
+                           num_steps_per_year,
+                           num_paths)
+
+    d = option.delta(valuation_date,
+                     spot_fx_rate,
+                     domCurve,
+                     forCurve,
+                     model)
+
+    g = option.gamma(valuation_date,
+                     spot_fx_rate,
+                     domCurve,
+                     forCurve,
+                     model)
+
+    v = option.vega(valuation_date,
+                     spot_fx_rate,
+                     domCurve,
+                     forCurve,
+                     model)
+
+    # I SHOULD GET 49.4934% OR 494,934 in EUR
+    # VEGA IS 68,777.26
+    # GAMMA IS 916,285
+    # DELTA IS -9560266
+    
+    print(optionType)
+    print("Value:", v)
+    print("Value MC:", v_mc)
+    print("Delta: ", d)
+    print("Gamma:", g)
+    print("Vega:", v)
 
 ###############################################################################
 
 
 test_FinFXOneTouchOption()
+test_BBGOneTouchOption()
 testCases.compareTestCases()
