@@ -2,27 +2,31 @@
 # Copyright (C) 2018, 2019, 2020 Dominic O'Kane
 ###############################################################################
 
-from FinTestCases import FinTestCases, globalTestCaseMode
-from financepy.products.rates.ois import OIS
-from financepy.products.rates.ois_curve import OISCurve
-from financepy.products.rates.dual_curve import IborDualCurve
-from financepy.products.rates.ibor_single_curve import IborSingleCurve
-from financepy.utils.global_types import SwapTypes
-from financepy.utils.math import ONE_MILLION
-from financepy.market.curves.interpolator import InterpTypes
-from financepy.products.rates.ibor_swap import IborSwap
-from financepy.products.rates.ibor_deposit import IborDeposit
-from financepy.products.rates.ibor_future import IborFuture
-from financepy.products.rates.ibor_fra import IborFRA
-from financepy.utils.frequency import FrequencyTypes
-from financepy.utils.day_count import DayCountTypes
-from financepy.utils.date import Date
-import matplotlib.pyplot as plt
-import numpy as np
-
 import sys
 sys.path.append("..")
 
+from FinTestCases import FinTestCases, globalTestCaseMode
+
+from financepy.utils.frequency import FrequencyTypes
+from financepy.utils.date import Date
+from financepy.utils.day_count import DayCountTypes
+
+from financepy.products.rates.ibor_fra import IborFRA
+from financepy.products.rates.ibor_future import IborFuture
+from financepy.products.rates.ibor_deposit import IborDeposit
+from financepy.products.rates.ibor_swap import IborSwap
+from financepy.market.curves.interpolator import InterpTypes
+
+from financepy.utils.math import ONE_MILLION
+from financepy.utils.global_types import SwapTypes
+
+from financepy.products.rates.ibor_single_curve import IborSingleCurve
+from financepy.products.rates.dual_curve import IborDualCurve
+from financepy.products.rates.ois_curve import OISCurve
+from financepy.products.rates.ois import OIS
+
+import numpy as np
+import matplotlib.pyplot as plt
 
 testCases = FinTestCases(__file__, globalTestCaseMode)
 
@@ -260,7 +264,7 @@ def test_bloombergPricingExample():
         valuation_date, libor_curve, libor_curve, None))
     testCases.print("FIXED:", swaps[0]._fixed_leg.value(
         valuation_date, libor_curve))
-    testCases.print("FLOAT:", swaps[0]._floatLeg.value(
+    testCases.print("FLOAT:", swaps[0]._float_leg.value(
         valuation_date, libor_curve, libor_curve, None))
 
     testCases.banner("======================================================")
@@ -270,7 +274,7 @@ def test_bloombergPricingExample():
         settlement_date, libor_curve, libor_curve, None))
     testCases.print("FIXED:", swaps[0]._fixed_leg.value(
         settlement_date, libor_curve))
-    testCases.print("FLOAT:", swaps[0]._floatLeg.value(
+    testCases.print("FLOAT:", swaps[0]._float_leg.value(
         settlement_date, libor_curve, libor_curve, None))
     testCases.banner("======================================================")
 
@@ -291,7 +295,7 @@ def test_bloombergPricingExample():
         valuation_date, oisCurve, liborDualCurve, None))
     testCases.print("FIXED:", swaps[0]._fixed_leg.value(
         valuation_date, oisCurve))
-    testCases.print("FLOAT:", swaps[0]._floatLeg.value(
+    testCases.print("FLOAT:", swaps[0]._float_leg.value(
         valuation_date, oisCurve, libor_curve, None))
 
     testCases.header("VALUATION TO SWAP SETTLEMENT DATE", " PV")
@@ -299,7 +303,7 @@ def test_bloombergPricingExample():
         settlement_date, oisCurve, liborDualCurve, None))
     testCases.print("FIXED:", swaps[0]._fixed_leg.value(
         settlement_date, oisCurve))
-    testCases.print("FLOAT:", swaps[0]._floatLeg.value(
+    testCases.print("FLOAT:", swaps[0]._float_leg.value(
         settlement_date, oisCurve, liborDualCurve, None, ))
 
 #    swaps[0].print_fixed_leg_pv()
