@@ -2,24 +2,23 @@
 # Copyright (C) 2018, 2019, 2020 Dominic O'Kane
 ##############################################################################
 
-from FinTestCases import FinTestCases, globalTestCaseMode
-from financepy.utils.global_types import FinExerciseTypes
-from financepy.utils.helpers import print_tree
-from financepy.models.bdt_tree import BDTTree
-from financepy.market.curves.discount_curve_zeros import DiscountCurveZeros
-from financepy.utils.global_vars import gDaysInYear
-from financepy.utils.day_count import DayCountTypes
-from financepy.utils.frequency import FrequencyTypes
-from financepy.models.black import Black
-from financepy.products.rates.ibor_swaption import SwapTypes
-from financepy.products.rates.ibor_swaption import IborSwaption
-from financepy.products.bonds.bond import Bond
-from financepy.market.curves.discount_curve_flat import DiscountCurveFlat
-from financepy.market.curves.discount_curve import DiscountCurve
-from financepy.utils.date import Date
-import numpy as np
 import matplotlib.pyplot as plt
-
+import numpy as np
+from financepy.utils.date import Date
+from financepy.market.curves.discount_curve import DiscountCurve
+from financepy.market.curves.discount_curve_flat import DiscountCurveFlat
+from financepy.products.bonds.bond import Bond
+from financepy.products.rates.ibor_swaption import IborSwaption
+from financepy.products.rates.ibor_swaption import SwapTypes
+from financepy.models.black import Black
+from financepy.utils.frequency import FrequencyTypes
+from financepy.utils.day_count import DayCountTypes
+from financepy.utils.global_vars import gDaysInYear
+from financepy.market.curves.discount_curve_zeros import DiscountCurveZeros
+from financepy.models.bdt_tree import BDTTree
+from financepy.utils.helpers import print_tree
+from financepy.utils.global_types import FinExerciseTypes
+from FinTestCases import FinTestCases, globalTestCaseMode
 import sys
 sys.path.append("..")
 
@@ -126,17 +125,17 @@ def test_BDTExampleTwo():
     coupon_times = []
     coupon_flows = []
     cpn = bond._coupon/bond._frequency
-    num_flows = len(bond._flow_dates)
+    num_flows = len(bond._coupon_dates)
 
     for i in range(1, num_flows):
-        pcd = bond._flow_dates[i-1]
-        ncd = bond._flow_dates[i]
+        pcd = bond._coupon_dates[i-1]
+        ncd = bond._coupon_dates[i]
         if pcd < settlement_date and ncd > settlement_date:
             flow_time = (pcd - settlement_date) / gDaysInYear
             coupon_times.append(flow_time)
             coupon_flows.append(cpn)
 
-    for flow_date in bond._flow_dates:
+    for flow_date in bond._coupon_dates:
         if flow_date > settlement_date:
             flow_time = (flow_date - settlement_date) / gDaysInYear
             coupon_times.append(flow_time)
@@ -248,7 +247,7 @@ def test_BDTExampleThree():
                 coupon_times = []
                 coupon_flows = []
                 cpn = bond._coupon/bond._frequency
-                for flow_date in bond._flow_dates:
+                for flow_date in bond._coupon_dates:
                     if flow_date > expiry_date:
                         flow_time = (flow_date - settlement_date) / gDaysInYear
                         coupon_times.append(flow_time)
