@@ -2,19 +2,18 @@
 # Copyright (C) 2018, 2019, 2020 Dominic O'Kane
 ##############################################################################
 
-from FinTestCases import FinTestCases, globalTestCaseMode
-from financepy.utils.global_types import FinExerciseTypes
-from financepy.models.bk_tree import BKTree
-from financepy.utils.helpers import print_tree
-from financepy.utils.global_vars import gDaysInYear
-from financepy.utils.day_count import DayCountTypes
-from financepy.utils.frequency import FrequencyTypes
-from financepy.products.bonds.bond import Bond
-from financepy.market.curves.discount_curve import DiscountCurve
-from financepy.utils.date import Date
-import numpy as np
 import time
-
+import numpy as np
+from financepy.utils.date import Date
+from financepy.market.curves.discount_curve import DiscountCurve
+from financepy.products.bonds.bond import Bond
+from financepy.utils.frequency import FrequencyTypes
+from financepy.utils.day_count import DayCountTypes
+from financepy.utils.global_vars import gDaysInYear
+from financepy.utils.helpers import print_tree
+from financepy.models.bk_tree import BKTree
+from financepy.utils.global_types import FinExerciseTypes
+from FinTestCases import FinTestCases, globalTestCaseMode
 import sys
 sys.path.append("..")
 
@@ -73,17 +72,17 @@ def test_BKExampleTwo():
     coupon_times = []
     coupon_flows = []
     cpn = bond._coupon/bond._frequency
-    num_flows = len(bond._flow_dates)
+    num_flows = len(bond._coupon_dates)
 
     for i in range(1, num_flows):
-        pcd = bond._flow_dates[i-1]
-        ncd = bond._flow_dates[i]
+        pcd = bond._coupon_dates[i-1]
+        ncd = bond._coupon_dates[i]
         if pcd < settlement_date and ncd > settlement_date:
             flow_time = (pcd - settlement_date) / gDaysInYear
             coupon_times.append(flow_time)
             coupon_flows.append(cpn)
 
-    for flow_date in bond._flow_dates:
+    for flow_date in bond._coupon_dates:
         if flow_date > settlement_date:
             flow_time = (flow_date - settlement_date) / gDaysInYear
             coupon_times.append(flow_time)
