@@ -2,19 +2,18 @@
 # Copyright (C) 2018, 2019, 2020 Dominic O'Kane
 ##############################################################################
 
-from FinTestCases import FinTestCases, globalTestCaseMode
-from financepy.utils.global_types import FinExerciseTypes
-from financepy.utils.helpers import print_tree
-from financepy.utils.global_vars import gDaysInYear
-from financepy.utils.day_count import DayCountTypes
-from financepy.utils.frequency import FrequencyTypes
-from financepy.products.bonds.bond import Bond
-from financepy.market.curves.discount_curve_flat import DiscountCurveFlat
-from financepy.models.hw_tree import HWTree, FinHWEuropeanCalcType
-from financepy.utils.date import Date
-import numpy as np
 import time
-
+import numpy as np
+from financepy.utils.date import Date
+from financepy.models.hw_tree import HWTree, FinHWEuropeanCalcType
+from financepy.market.curves.discount_curve_flat import DiscountCurveFlat
+from financepy.products.bonds.bond import Bond
+from financepy.utils.frequency import FrequencyTypes
+from financepy.utils.day_count import DayCountTypes
+from financepy.utils.global_vars import gDaysInYear
+from financepy.utils.helpers import print_tree
+from financepy.utils.global_types import FinExerciseTypes
+from FinTestCases import FinTestCases, globalTestCaseMode
 import sys
 sys.path.append("..")
 
@@ -96,11 +95,13 @@ def test_HullWhiteExampleTwo():
 
         model = HWTree(sigma, a, num_time_steps)
         model.build_tree(texp, times, dfs)
-        vTree1 = model.option_on_zero_coupon_bond_tree(texp, tmat, strike, face)
+        vTree1 = model.option_on_zero_coupon_bond_tree(
+            texp, tmat, strike, face)
 
         model = HWTree(sigma, a, num_time_steps+1)
         model.build_tree(texp, times, dfs)
-        vTree2 = model.option_on_zero_coupon_bond_tree(texp, tmat, strike, face)
+        vTree2 = model.option_on_zero_coupon_bond_tree(
+            texp, tmat, strike, face)
 
         end = time.time()
         period = end-start
@@ -136,11 +137,11 @@ def test_HullWhiteBondOption():
     coupon_flows = []
     cpn = bond._coupon/bond._frequency
 
-    num_flows = len(bond._flow_dates)
+    num_flows = len(bond._coupon_dates)
     for i in range(1, num_flows):
 
-        pcd = bond._flow_dates[i-1]
-        ncd = bond._flow_dates[i]
+        pcd = bond._coupon_dates[i-1]
+        ncd = bond._coupon_dates[i]
 
         if ncd > settlement_date:
 
@@ -233,7 +234,7 @@ def test_HullWhiteCallableBond():
     coupon_flows = []
     cpn = bond._coupon/bond._frequency
 
-    for flow_date in bond._flow_dates[1:]:
+    for flow_date in bond._coupon_dates[1:]:
 
         if flow_date > settlement_date:
             flow_time = (flow_date - settlement_date) / gDaysInYear
@@ -301,7 +302,7 @@ def test_HullWhiteCallableBond():
     dfs = []
     times = []
 
-    for dt in bond._flow_dates:
+    for dt in bond._coupon_dates:
         if dt > settlement_date:
             t = (dt - settlement_date) / gDaysInYear
             df = curve.df(dt)
